/*---------------------------------------------------------------------------*/
/*   Copyright (C)       Endress+Hauser (2002). All Rights Reserved          */
/*                                                                           */
/*   Product:            SIMATIC PDM                                         */
/*                                                                           */
/*   Device:             CAPACITIVE LEVEL DEVICE MULTICAP PA for Profibus    */
/*   Function:           Device Description Implementation for FEC14         */
/*   Description:        Device Description                                  */
/*   Filename:           PA_SENSOR_LEVEL_EH_MULTICAP_V01.ddl                 */
/*   Dictionary:         PA_SENSOR_LEVEL_EH_MULTICAP_V01.dct                 */
/*                                                                           */
/*   Manufactor:         Endress & Hauser GmbH & Co.                         */
/*                       Hauptstrasse 1                                      */
/*                       D-79689 Maulburg                                    */
/*                                                                           */
/*   Author:             Julien Messer                                       */
/*                       E+H Process Solutions AG                            */
/*                                                                           */
/*  $Revision:            1.0$                                               */
/*  $Date:                02.07.03$                                          */
/*  Obere Revision fr QVCS, untere fr DD, unten die aktuelle angeben       */
/*  Revision:1.0                                                             */
/*  Date:02.07.03                                                            */
/*---------------------------------------------------------------------------*/


MANUFACTURER		17,
DEVICE_TYPE		1,
DEVICE_REVISION 	0x0300,
DD_REVISION		1

/* Defines */

#define NO_func1_AI_out_unit_text

#define DEFINE_TRANS1_LEVEL_UNIT SELECT (trans1_level_unit) { \
		CASE 1342:   "%"; \
		CASE 1012:   "cm"; \
		CASE 1013:   "mm"; \
		CASE 1010:   "m"; \
		CASE 1019:   "inch"; \
		CASE 1018:   "ft"; \
		DEFAULT:  "%"; \
	}

#define DEFINE_TRANS1_LEVEL_UNIT_MIN_RELATION(value) SELECT (trans1_level_unit) { \	// Used to define MIN values
		CASE 1342:   0; \
		CASE 1012:   value * 100; \
		CASE 1013:   value * 1000; \
		CASE 1010:   value; \
		CASE 1019:   value * 39.37008; \
		CASE 1018:   value * 3.28084; \
		DEFAULT:  0; \
	}

#define DEFINE_TRANS1_LEVEL_UNIT_MAX_RELATION(value) SELECT (trans1_level_unit) { \	// Used to define MAX values
		CASE 1342:   100; \
		CASE 1012:   value * 100; \
		CASE 1013:   value * 1000; \
		CASE 1010:   value; \
		CASE 1019:   value * 39.37009; \
		CASE 1018:   value * 3.28085; \
		DEFAULT:  100; \
	}

#define DEFINE_TRANS1_PRIMARY_VALUE_UNIT SELECT (trans1_primary_value_unit) { \
		CASE 1342: "|en|%"; \ 
		CASE 1012: "|en|cm|de|cm|fr|cm|it|cm"; \ 
		CASE 1013: "|en|mm"; \ 
		CASE 1010: "|en|m"; \ 
		CASE 1019: "|en|inch"; \ 
		CASE 1018: "|en|ft"; \ 
		CASE 1038: "|en|l"; \ 
		CASE 1042: "|en|hl"; \ 
		CASE 1036: "|en|cm3"; \ 
		CASE 1035: "|en|dm3"; \ 
		CASE 1034: "|en|m3"; \ 
		CASE 1043: "|en|ft3"; \ 
		CASE 1048: "|en|usgal"; \ 
		CASE 1049: "|en|i gal"; \ 
		CASE 1088: "|en|kg"; \ 
		CASE 1092: "|en|t"; \ 
		CASE 1094: "|en|lb"; \ 
		DEFAULT:  "%"; \
	}

#define Hnd000	(parWriteLocking == 2457)
#define Hnd001	(trans1_calibration_type == 0)
#define Hnd002	(trans1_calibration_type_offline == 0)
#define Hnd003  (func1_AI_target_mode == 16)
#define Val000  (parPASelectMainValue == 1)

#define ENABLE_IDENTCHECK
#define CHECK_PROFILE_REV 0x300
#define DEFAULT_MANUFACTURER_ID 17
#define	CHECK_DEVICE_TYPE "Multicap"
//#define CHECK_SOFTWARE_VERSION 1.0 es wird eine V1.1 geben welche kompatibel ist
#include "SIPAST.inc"

/** ----------------------------------------------------------------
  *    Imported/redefined part
  * ----------------------------------------------------------------
  */

IMPORT "EHPA_LEVEL_PROFIL3.imp"
{
	EVERYTHING;

	REDEFINITIONS
	{
		VARIABLE phys_tag_desc
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
		}

		VARIABLE trans1_primary_value_unit	// parPVUnit
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE ENUMERATED(2)
			{
				DEFAULT_VALUE 1342;
				{ 1342 ,"|en|%"}, 
				{ 1012 ,"|en|cm|de|cm|fr|cm|it|cm"}, 
				{ 1013 ,"|en|mm"}, 
				{ 1010 ,"|en|m"}, 
				{ 1019 ,"|en|inch"}, 
				{ 1018 ,"|en|ft"}, 
				{ 1038 ,"|en|l"}, 
				{ 1042 ,"|en|hl"}, 
				{ 1036 ,"|en|cm3"}, 
				{ 1035 ,"|en|dm3"}, 
				{ 1034 ,"|en|m3"}, 
				{ 1043 ,"|en|ft3"}, 
				{ 1048 ,"|en|usgal"}, 
				{ 1049 ,"|en|i gal"}, 
				{ 1088 ,"|en|kg"}, 
				{ 1092 ,"|en|t"}, 
				{ 1094 ,"|en|lb"}	
			}		
		}
		
		VARIABLE trans1_level_unit		// parLevelUnit
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE ENUMERATED (2)
			{
				{ 1342, "%" },
				{ 1012, "cm" },
				{ 1013, "mm" },
				{ 1010, "m" },
				{ 1019, "inch" },
				{ 1018, "ft" }
			}			
		}

		VARIABLE trans1_calibration_type	// parCalType
		{
			REDEFINE VALIDITY TRUE;
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE ENUMERATED (1)
			{  
				DEFAULT_VALUE 0;
				{ 1 ,"Online"}, 
				{ 0 ,"Offline"}  
			}
		}

		VARIABLE trans1_lin_type		// parLinType
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE ENUMERATED (1)
			{
				DEFAULT_VALUE 0;
				{ 0 ,"|en|vertical|de|stehend|fr|verticale|it|verticale"}, 
				{ 20 ,"|en|horizontal|de|liegend|fr|horizontale|it|orizzontale"}  
			}			
		}
		
		VARIABLE trans1_cal_point_lo		// parCalPointLo
		{
			REDEFINE CLASS DYNAMIC;
			REDEFINE CONSTANT_UNIT "pF";
			REDEFINE HANDLING IF (Hnd000 && Hnd001) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 0;
				MIN_VALUE 0.0;
				MAX_VALUE 2100.0;				
			}
		}

		VARIABLE trans1_level_lo		// parLevelLo
		{
			REDEFINE CONSTANT_UNIT DEFINE_TRANS1_LEVEL_UNIT;
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DISPLAY_FORMAT	"10.3f" ;
				EDIT_FORMAT	"10.3f" ;
				DEFAULT_VALUE 0;
				MIN_VALUE DEFINE_TRANS1_LEVEL_UNIT_MIN_RELATION(-9999.0)
				MAX_VALUE DEFINE_TRANS1_LEVEL_UNIT_MAX_RELATION(9999.0)
			}
		}
		
		VARIABLE trans1_cal_point_hi		// parCalPointHi
		{
			REDEFINE CLASS DYNAMIC;
			REDEFINE CONSTANT_UNIT "pF";
			REDEFINE HANDLING IF (Hnd000 && Hnd001) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 2000;
				MIN_VALUE 0.0;
				MAX_VALUE 2100.0;				
			}
		}
		
		VARIABLE trans1_level_hi		// parLevelHi
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE CONSTANT_UNIT DEFINE_TRANS1_LEVEL_UNIT;
			REDEFINE TYPE FLOAT
			{
				DISPLAY_FORMAT	"10.3f" ;
				EDIT_FORMAT	"10.3f" ;
				DEFAULT_VALUE 100;
				MIN_VALUE DEFINE_TRANS1_LEVEL_UNIT_MIN_RELATION(-9999.0)
				MAX_VALUE DEFINE_TRANS1_LEVEL_UNIT_MAX_RELATION(9999.0)
			}
		}
		
		VARIABLE func1_AI_hi_hi_lim		// parHiHiLimit
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 100;
			}
			
		}
		
		VARIABLE func1_AI_hi_lim		// parHiLimit
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 95;
			}
		}

		VARIABLE func1_AI_lo_lo_lim		// parLoLoLimit
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 0;
			}
		}

		VARIABLE func1_AI_lo_lim		// parLoLimit
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 5;
			}
		}

		VARIABLE func1_AI_alarm_hys		// parAlarmHys
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 5;
			}
		}

		VARIABLE func1_AI_pv_lower_range_value	// parPvScale1
		{
			REDEFINE CONSTANT_UNIT DEFINE_TRANS1_PRIMARY_VALUE_UNIT;
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
		}
		
		VARIABLE func1_AI_pv_upper_range_value	// parPvScale2
		{
			REDEFINE CONSTANT_UNIT DEFINE_TRANS1_PRIMARY_VALUE_UNIT;
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 100;
			}
		}
		
		VARIABLE func1_AI_out_lower_range_value	// parOutScale1
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
		}
		
		VARIABLE func1_AI_out_upper_range_value	// parOutScale2
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 100;
			}			
		}

		VARIABLE phys_ident_number		// parPAIdentNumberSelector
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE ENUMERATED (1)
			{
				DEFAULT_VALUE 1;
			}
		}

		VARIABLE func1_AI_target_mode		// parTargetMode
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE ENUMERATED (1)
			{
				{ 8 ,"|en|auto"}, 
				{ 16 ,"|en|manual"}, 
				{ 128 ,"|en|out_of_service"}
			}	
		}

		VARIABLE func1_AI_out_unit		// parOutUnit
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE ENUMERATED(2)
			{
				DEFAULT_VALUE 1342;
				{ 1342 ,"|en|%"}, 
				{ 1012 ,"|en|cm|de|cm|fr|cm|it|cm"}, 
				{ 1013 ,"|en|mm"}, 
				{ 1010 ,"|en|m"}, 
				{ 1019 ,"|en|inch"}, 
				{ 1018 ,"|en|ft"}, 
				{ 1038 ,"|en|l"}, 
				{ 1042 ,"|en|hl"}, 
				{ 1036 ,"|en|cm3"}, 
				{ 1035 ,"|en|dm3"}, 
				{ 1034 ,"|en|m3"}, 
				{ 1043 ,"|en|ft3"}, 
				{ 1048 ,"|en|usgal"}, 
				{ 1049 ,"|en|i gal"}, 
				{ 1088 ,"|en|kg"}, 
				{ 1092 ,"|en|t"}, 
				{ 1094 ,"|en|lb"}	
			}	
		}

		VARIABLE func1_AI_out_value		// parPAAIOutValue
		{
			REDEFINE HANDLING IF (Hnd000 && Hnd003) { READ&WRITE; } ELSE { READ; }			
			REDEFINE TYPE  FLOAT  {
				DEFAULT_VALUE	0.0 ;
			}						
		}
		
		VARIABLE trans1_primary_value_value
		{
			REDEFINE CONSTANT_UNIT DEFINE_TRANS1_PRIMARY_VALUE_UNIT
			REDEFINE TYPE FLOAT {
				DISPLAY_FORMAT	"10.2f" ;
				DEFAULT_VALUE 0.0;
			}
		}
				
		VARIABLE phys_device_id			// parDeviceIDNumber
		{
			REDEFINE TYPE ASCII (16)
			{
				DEFAULT_VALUE "Multicap";
			}
		}
		
		VARIABLE func1_AI_pv_ftime		// parDamping
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 0;
				MIN_VALUE 0.0;
				MAX_VALUE 40.0;
			}
		}
		
		VARIABLE phys_descriptor		// parDescriptor
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
		}
		
		VARIABLE phys_software_rev		// parSoftwareRevision
		{
			TYPE ASCII (16)
			{
				DEFAULT_VALUE	"1.0";
			}
		}
		
		VARIABLE phys_hardware_rev		// parHardwareRevision
		{
			TYPE ASCII (16)
			{
				DEFAULT_VALUE	"1.0";
			}
		}
		
		VARIABLE trans1_min_sensor_value	// parMinMeasuredValue
		{
			REDEFINE CONSTANT_UNIT "pF";
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 0;
				MIN_VALUE -80.0;
				MAX_VALUE 3000.0;				
			}			
		}
		
		VARIABLE trans1_max_sensor_value	// parMaxMeasuredValue
		{
			REDEFINE CONSTANT_UNIT "pF";
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 2100;
				MIN_VALUE -80.0;
				MAX_VALUE 3000.0;				
			}			
		}
		
		VARIABLE trans1_temperature		// parElectronicTemp
		{
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 21;
			}
		}
		
		VARIABLE trans1_temperature_unit	// parTempUnit
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE ENUMERATED (2)
			{
				DEFAULT_VALUE	1001;
				{ 1001 ,"|en|C"}, 
				{ 1002 ,"|en|F"}, 
				{ 1000 ,"|en|K"}
			}
		}
		
		VARIABLE trans1_min_temperature		// parMinMeasuredTemperature
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE -40;
				MIN_VALUE -40.0;
				MAX_VALUE 80.0;
			}			
		}
		
		VARIABLE trans1_max_temperature		// parMaxMeasuredTemperature
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 80;
				MIN_VALUE -40.0;
				MAX_VALUE 80.0;			
			}			
		}

		VARIABLE trans1_sensor_value
		{
			REDEFINE CONSTANT_UNIT "pF";
			REDEFINE TYPE FLOAT
			{
				DISPLAY_FORMAT	"10.0f" ;
				DEFAULT_VALUE 200;
			}
		}
		
		VARIABLE func1_AI_simulation_enabled		// parSimulation
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
		}
		
		VARIABLE func1_AI_simulate_value		// parPASimulationValue
		{
			REDEFINE CONSTANT_UNIT DEFINE_TRANS1_PRIMARY_VALUE_UNIT;
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
			REDEFINE TYPE FLOAT
			{
				DEFAULT_VALUE 20;
			}
		}
		
		VARIABLE phys_message
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }			
		}

		VARIABLE phys_install_date
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }			
		}

		VARIABLE func1_AI_batch_id
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }			
		}

		VARIABLE func1_AI_batch_unit
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }			
		}

		VARIABLE func1_AI_batch_operation
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }			
		}

		VARIABLE func1_AI_batch_phase
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }			
		}

		VARIABLE func1_AI_out_decimal_point
		{
			REDEFINE HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }			
		}
		
		VARIABLE trans1_level
		{ 			
			REDEFINE TYPE FLOAT
			{
				DISPLAY_FORMAT	"10.2f" ;
				DEFAULT_VALUE 50;
			}
		}
		
		VARIABLE phys_device_man_id {
			REDEFINE TYPE ENUMERATED (2) {
				DEFAULT_VALUE 17;
			}
		}
		
		VARIABLE trans1_blk_class {
			REDEFINE TYPE ENUMERATED (1) {
				DEFAULT_VALUE 4;
			}
		}
		
		VARIABLE trans1_sensor_low_limit {
			REDEFINE TYPE FLOAT {
				DEFAULT_VALUE 0;
			}
		}

		VARIABLE trans1_sensor_high_limit {
			REDEFINE TYPE FLOAT {
				DEFAULT_VALUE 100;
			}
		}
	
/* Redefinition of standard online menus */

		MENU OnlineWindow_display
		{
			REDEFINE ITEMS
			{
				Page_display_func1,
				Page_display_value
			}
		}

		MENU Page_display_func1
		{
			REDEFINE LABEL "Function Block 1 - Analog Input";
		}

		MENU Menu_S_Device 
		{
			REDEFINE ITEMS 
			{ 
				std_NodeAddress,
				SEPARATOR,
				std_LoadinDevice,
				std_LoadinPC,
				SEPARATOR,
				OnlineDialog_Simulation,				
				OnlineDialog_Reset,
				OnlineDialog_SetUnitToBus,
				SEPARATOR,
				OnlineDialog_Adjust_BasicSetup,
				OnlineDialog_extended_calibration,
				OnlineDialog_profibus_parameter,
				OnlineDialog_system_parameter,
				OnlineDialog_security_settings,
				OnlineDialog_Adjust_Service,
				SEPARATOR,
				OnlineDialog_write_locking
			} 
		}

		MENU Menu_S_View 
		{
			REDEFINE ITEMS 
			{ 
				OnlineWindow_display,
	        		OnlineWindow_yt,
				OnlineWindow_S_alarm_func1,
				OnlineWindow_diagnosis,
				SEPARATOR,
				std_Funktionsleiste,
				std_Statuszeile,
				SEPARATOR,
				std_Update
			} 
		}
		
		MENU OnlineWindow_S_alarm_func1
		{
			REDEFINE LABEL "|en|Output|de|Ausgang";
		}
		
		MENU Page_diagnosis_func1
		{
			REDEFINE LABEL "|en|Output|de|Ausgang";
		}

/* Redefinition of standard offline menus */

		MENU Table_Main_Specialist
		{
			REDEFINE LABEL	"Multicap FEC14";
			REDEFINE ITEMS
			{
				Tab_s_EH_Std_Matrix,
				Tab_s_PA_Profil
			}
		}
		
		MENU Table_Main_Maintenance
		{
			REDEFINE LABEL	"Multicap FEC14";
			REDEFINE ITEMS
			{
				Tab_s_EH_Std_Matrix,
				Tab_s_PA_Profil
			}
		}	

		MENU Tab_s_output
		{
			REDEFINE ITEMS
			{
				Tab_s_func1
			}
		}

		MENU Tab_s_func1
		{
			REDEFINE ITEMS
			{
				func1_AI_st_rev,	
				func1_AI_out_unit,
				func1_AI_pv_ftime,
				Tab_s_func1_batch,
				Tab_s_func1_pv_range,
				Tab_s_func1_outscale,
				Tab_s_func1_limits,
		//		Tab_s_func1_FSafe,		// Removed by JM
				Tab_s_func1_interface		
			}
		}

		MENU download_variables
		{
			PRE_READ_ACTIONS {
				downloadVariablesPreReadActions
			}
			REDEFINE ITEMS
			{
				phys_blk_profile_rev,
				phys_st_rev,
				phys_tag_desc,
				func1_AI_target_mode,
				phys_software_rev,
				phys_hardware_rev,
				phys_device_man_id,
				phys_device_id,
				phys_device_ser_num,
				phys_device_certification,
				phys_descriptor,
				phys_message,
				phys_install_date,
				phys_ident_number,
				trans1_primary_value_value,
				trans1_primary_value_unit,
				trans1_blk_class,				
				trans1_st_rev,
				trans1_sensor_high_limit,
				trans1_sensor_low_limit,
				trans1_level,
				trans1_level_unit,
				trans1_sensor_value,
				trans1_min_sensor_value,
				trans1_max_sensor_value,				
				trans1_temperature,
				trans1_temperature_unit,
				trans1_max_temperature,
				trans1_min_temperature,
				trans1_lin_type,
				trans1_level_lo_offline,
				trans1_level_hi_offline,
				trans1_cal_point_lo_offline,
				trans1_cal_point_hi_offline,
				trans1_calibration_type_offline,
				parBargraphScaleMin_offline,
				parBargraphScaleMax_offline,
					
				func1_AI_st_rev,
				func1_AI_out_unit,
				func1_AI_out_value,
				parPAAIOutStatus,
				func1_AI_pv_ftime,
				func1_AI_batch_id,
				func1_AI_batch_unit,
				func1_AI_batch_operation,
				func1_AI_batch_phase,
				func1_AI_pv_lower_range_value,
				func1_AI_pv_upper_range_value,
				func1_AI_out_lower_range_value,
				func1_AI_out_upper_range_value,
				func1_AI_lo_lo_lim,
				func1_AI_lo_lim,
				func1_AI_hi_lim,
				func1_AI_hi_hi_lim,
				func1_AI_alarm_hys,
				func1_AI_hi_hi_alm_state,
				func1_AI_hi_alm_state,
				func1_AI_lo_alm_state,
				func1_AI_lo_lo_alm_state,
				func1_AI_out_decimal_point,
				func1_AI_simulation_enabled,
				func1_AI_simulate_value,
				parSimulationStatus,				
				
				parPADeviceBusAddress,
				parPASelectMainValue,
				parPASetUnitToBus,
				parActualError,
				parLastError,
				parClearLastError,
				parSystemstartsCounter
			}
		}

		MENU upload_variables {
			REDEFINE PRE_WRITE_ACTIONS {
				uploadVariablesPreWriteActions
			}
			REDEFINE ITEMS {
				IF ( Hnd000 ) { 
					trans1_primary_value_unit,
					trans1_level_unit
					IF ( Hnd002 ) {
						trans1_calibration_type_offline,
						trans1_cal_point_lo_offline,
						trans1_cal_point_hi_offline
						trans1_level_lo_offline,
						trans1_level_hi_offline,
						parBargraphScaleMin_offline,
						parBargraphScaleMax_offline
					}
					trans1_lin_type,
					func1_AI_hi_hi_lim,
					func1_AI_hi_lim,
					func1_AI_lo_lim,
					func1_AI_lo_lo_lim,
					func1_AI_alarm_hys,
					func1_AI_pv_ftime,
					func1_AI_pv_lower_range_value,
					func1_AI_pv_upper_range_value,
					func1_AI_out_lower_range_value,
					func1_AI_out_upper_range_value,
					func1_AI_target_mode,
					IF ( Hnd003 ) {
						func1_AI_out_value,
						parPAAIOutStatus						
					}
					phys_ident_number,
					parPASelectMainValue,
					func1_AI_out_unit,
					phys_descriptor,
					trans1_temperature_unit,
					phys_tag_desc,
					phys_message,
					phys_install_date,
					trans1_level_unit,
					trans1_temperature_unit,
					func1_AI_batch_id,
					func1_AI_batch_unit,
					func1_AI_batch_operation,
					func1_AI_batch_phase,
					func1_AI_out_decimal_point,
					parClearLastError
				}
			}
		}


		REDEFINE UNIT TB_LEVEL_UNIT
		{
			trans1_level_unit:
			
			trans1_level_lo,
			trans1_level_lo_offline,
			trans1_level_hi,
			trans1_level_hi_offline,
			// Original unit relations:
			trans1_level,
			trans1_full_cal,
			trans1_zero_offset,
			trans1_cylinder_diameter
		}
		
		REDEFINE UNIT AI_PV_SCALE_UNIT
		{
			trans1_primary_value_unit:
		
			func1_AI_pv_lower_range_value,
			func1_AI_pv_upper_range_value,
			func1_AI_simulate_value	
		}	
	}
}

#define YT1_LABEL		"|en|measured value|de|Messwert|fr|Valeur de mesure|es|Messwert|it|Valore di misura|nl|gemeten waarde"
#define YT1_VALUE		trans1_primary_value_value
#define	YT1_LRV			func1_AI_pv_lower_range_value
#define YT1_URV			func1_AI_pv_upper_range_value

#define YT2_LABEL		"|en|measured level|de|gemess. Fllst.|fr|Niveau mesur|es|gemess. Fllst.|it|Livello mis.|nl|gemeten niveau"
#define YT2_VALUE		trans1_level
#define	YT2_LRV			trans1_level_lo
#define YT2_URV			trans1_level_hi

#define YT3_LABEL		"|en|measured cap.|de|Messkapazitt|fr|capacit mesure|es|Messkapazitt|it|capacit di mis."
#define YT3_VALUE		trans1_sensor_value
#define	YT3_LRV			capacity_low_value
#define YT3_URV			capacity_high_value
#include "SI_YT.inc"

/** ----------------------------------------------------------------
  *    E+H Specific variables
  * ----------------------------------------------------------------
  */

VARIABLE parWriteLocking
{
	LABEL "|en|unlock parameter|de|Freigabecode|fr|Code opration|es|Freigabecode|it|Modo operativo|nl|startcode";
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	2457;
	}
	POST_READ_ACTIONS  { 
		updateParShowAccess
	}
}

COMMAND read_parWriteLocking
{
	BLOCK physical_block;
	INDEX 18;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parWriteLocking
		}
	}
}

COMMAND write_parWriteLocking
{
	BLOCK physical_block;
	INDEX 18;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parWriteLocking
		}
		REPLY
		{
		}
	}
}

VARIABLE parPASelectMainValue
{
	LABEL "|en|select v0h0|de|Zuordnung Anzei.|fr|Selection V0H0|es|Zuordnung Anzei.|it|Selezione V0H0";
	CLASS CONTAINED;
	HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
	TYPE ENUMERATED (1)
	{
		{ 0 ,"PV"}, 
		{ 1 ,"Input SPS"}
	}
}

COMMAND read_parPASelectMainValue
{
	BLOCK physical_block;
	INDEX 47;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parPASelectMainValue
		}
	}
}

COMMAND write_parPASelectMainValue
{
	BLOCK physical_block;
	INDEX 47;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parPASelectMainValue
		}
		REPLY
		{
		}
	}
}

VARIABLE parPASetUnitToBus
{
	LABEL "|en|set unit to bus|de|Setze Einh. Out|fr|Unite sur Sortie|es|Setze Einh. Out|it|Trasf. Unita Bus";
	CLASS CONTAINED;
	HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
	TYPE ENUMERATED (1)
	{
		{ 0 ,"|en|keep|de|beibehalten|fr|Garder|es|mantener|it|mantieni|nl|houden"}, 
		{ 1 ,"|en|confirm|de|besttigen|fr|validation|it|conferma"}
	}
}

parPASetUnitToBus_offline LIKE VARIABLE parPASetUnitToBus
{
	REDEFINE CLASS LOCAL;
	REDEFINE POST_EDIT_ACTIONS  {
		meth_set_unit_to_bus
	}
}

COMMAND read_parPASetUnitToBus
{
	BLOCK physical_block;
	INDEX 45;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parPASetUnitToBus
		}
	}
}

COMMAND write_parPASetUnitToBus
{
	BLOCK physical_block;
	INDEX 45;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parPASetUnitToBus
		}
		REPLY
		{
		}
	}
}

VARIABLE parBargraphScaleMin
{
	LABEL "|en|percent empty|de|Proz. Leerabgl.|fr|Pourcentage vide|es|Proz. Leerabgl.|it|perc. di vuoto|nl|leegpercentage";
	CLASS CONTAINED;
	HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
	CONSTANT_UNIT "%";
	TYPE FLOAT
	{
		DISPLAY_FORMAT	"10.3f" ;
		EDIT_FORMAT	"10.3f" ;
		DEFAULT_VALUE 0;
		MIN_VALUE 0.0;
		MAX_VALUE 100.0;
	}
}

COMMAND read_parBargraphScaleMin
{
	BLOCK transducer_block_1;
	INDEX 62;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parBargraphScaleMin
		}
	}
}

COMMAND write_parBargraphScaleMin
{
	BLOCK transducer_block_1;
	INDEX 62;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parBargraphScaleMin
		}
		REPLY
		{
		}
	}
}

VARIABLE parBargraphScaleMax
{
	LABEL "|en|percent full|de|Proz. Vollabgl.|fr|Pourcentageplein|es|Proz. Vollabgl.|it|perc. di pieno|nl|volpercentage";
	CLASS CONTAINED;
	HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
	CONSTANT_UNIT "%";
	TYPE FLOAT
	{
		DISPLAY_FORMAT	"10.3f" ;
		EDIT_FORMAT	"10.3f" ;
		DEFAULT_VALUE 100.0;
		MIN_VALUE 0.0;
		MAX_VALUE 100.0;
	}
}

COMMAND read_parBargraphScaleMax
{
	BLOCK transducer_block_1;
	INDEX 64;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parBargraphScaleMax
		}
	}
}

COMMAND write_parBargraphScaleMax
{
	BLOCK transducer_block_1;
	INDEX 64;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parBargraphScaleMax
		}
		REPLY
		{
		}
	}
}

VARIABLE parPADeviceBusAddress
{
	LABEL "|en|instrument addr.|de|Gerteadresse|fr|Adre.Instrument|es|Gerteadresse|it|Indrizzo Strum.";
	CLASS CONTAINED;
	HANDLING READ;
	TYPE UNSIGNED_INTEGER (1);
}

COMMAND read_parPADeviceBusAddress
{
	BLOCK physical_block;
	INDEX 43;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parPADeviceBusAddress
		}
	}
}

COMMAND write_parPADeviceBusAddress
{
	BLOCK physical_block;
	INDEX 43;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parPADeviceBusAddress
		}
		REPLY
		{
		}
	}
}

VARIABLE parSystemstartsCounter
{
	LABEL "|en|system starts|de|Systemstarts|fr|starts|es|Systemstarts|it|starts";
	CLASS CONTAINED;
	HANDLING READ;
	TYPE FLOAT
	{
		DEFAULT_VALUE 56;
	}
}

COMMAND read_parSystemstartsCounter
{
	BLOCK transducer_block_1;
	INDEX 63;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parSystemstartsCounter
		}
	}
}

VARIABLE parActualError
{
	LABEL "|en|present error|de|aktueller Fehler|fr|Dfaut actuel|es|aktueller Fehler|it|errore attuale|nl|actuele fout";
	HELP [error_code_help];
	CLASS DYNAMIC;
	HANDLING READ;
	TYPE ENUMERATED (2)
	{
		{ 0 ,"|en|E000: No Error"}, 
		{ 103 ,"|en|E103: Init active"}, 
		{ 106 ,"|en|E106: EEPROM Error"}, 
		{ 621 ,"|en|E621: Freq. CUF too low"}, 
		{ 661 ,"|en|E661: Elec. Temp too high"}, 
		{ 204 ,"|en|E204: Cap too high"}, 
		{ 203 ,"|en|E203: Cap too low"}, 
		{ 613 ,"|en|E613: Simmode active"}, 
		{ 617 ,"|en|E617: Delta C too small"}
	}
}

COMMAND read_parActualError
{
	BLOCK physical_block;
	INDEX 38;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parActualError
		}
	}
}

VARIABLE parLastError
{
	LABEL "|en|previous error|de|letzter Fehler|fr|Dernier dfaut|es|letzter Fehler|it|ultimo errore|nl|vorige fout";		
	HELP [error_code_help];	
	CLASS DYNAMIC;
	HANDLING READ;
	TYPE ENUMERATED (2)
	{
		{ 0 ,"|en|E000: No Error"}, 
		{ 103 ,"|en|E103: Init active"}, 
		{ 106 ,"|en|E106: EEPROM Error"}, 
		{ 621 ,"|en|E621: Freq. CUF too low"}, 
		{ 661 ,"|en|E661: Elec. Temp too high"}, 
		{ 204 ,"|en|E204: Cap too high"}, 
		{ 203 ,"|en|E203: Cap too low"}, 
		{ 613 ,"|en|E613: Simmode active"}, 
		{ 617 ,"|en|E617: Delta C too small"}
	}
}

COMMAND read_parLastError
{
	BLOCK physical_block;
	INDEX 39;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parLastError
		}
	}
}

VARIABLE parClearLastError
{
	LABEL "|en|clear last error|de|Lsche let.Fehl.|fr|Eff. der. dfaut|es|Lsche let.Fehl.|it|canc.ult. err.|nl|wis laatste fout";	
	CLASS CONTAINED;
	HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
	TYPE ENUMERATED (1)
	{
		{ 0 ,"|en|keep|de|beibehalten|fr|Garder|es|mantener|it|mantieni|nl|houden"}, 
		{ 1 ,"|en|erase|de|lschen|fr|Effacer|es|borrar|it|cancella|nl|wissen"}
	}
}

COMMAND read_parClearLastError
{
	BLOCK physical_block;
	INDEX 49;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parClearLastError
		}
	}
}

COMMAND write_parClearLastError
{
	BLOCK physical_block;
	INDEX 49;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parClearLastError
		}
		REPLY
		{
		}
	}
}

VARIABLE parReset			// parReset
{
	LABEL "reset";			
	HELP "|en|for reset code\nsee manual|de|Zur Codeeingabe\nsiehe Betriebsanl.|fr|pour code r..z.\nvoir mise en serv.|es|cdigo de borrado\nver manual|it|per codice reset\nvedi manuale|nl|voor resetcode\nzie handboek"; LABEL "|en|reset|de|Rcksetzen|fr|Remise  zro|es|Rcksetzen|it|reset|nl|reset";
	CLASS CONTAINED;
	HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
	TYPE UNSIGNED_INTEGER (2);
}

COMMAND read_parReset
{
	BLOCK physical_block;
	INDEX 19;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parReset
		}
	}
}

COMMAND write_parReset
{
	BLOCK physical_block;
	INDEX 19;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parReset
		}
		REPLY
		{
		}
	}
}

VARIABLE parShowAccess 
{
	LABEL 	"|en|Access rights|de|Zugriff|fr|Droits d'accs" ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	
	{  
		DEFAULT_VALUE   4;
		{ 0, "|en|Locked|de|Verriegelt|fr|Verrouill"},
		{ 2 ,"|en|Service (View only)|de|Service (nur Ansicht)|fr|Service (Consultation)"}, 
		{ 3 ,"|en|Service|de|Service|fr|Service"},
		{ 4, "|en|Customer|de|Kunde|fr|Client"},
		{ 5, "|en|WHG|de|WHG|fr|WHG"},
		{ 6, "|en|Debug unlock|de|Debug unlock|fr|Debug unlock"},
		{ 7, "|en|Hard lock|de|Hard lock|fr|Hard lock"}
	}
}

COMMAND read_trans1_calibration_type
{
	BLOCK transducer_block_1;
	INDEX 19;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{			
		}
		REPLY
		{
			trans1_calibration_type
		}
	}
}

VARIABLE parSimulationStatus
{
	LABEL "|en|sim. status|de|Sim. Status|fr|Etat simulation|es|Sim. Status|it|simul stato.|nl|simulatie status";
	CLASS CONTAINED & SERVICE;
	HANDLING IF (Hnd000) { READ&WRITE; } ELSE { READ; }
	TYPE UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE 0;
	}
}

COMMAND read_parSimulation
{
	BLOCK function_block_1;
	INDEX 34;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parSimulationStatus,
			func1_AI_simulate_value, 
			func1_AI_simulation_enabled
		}
	}
}

COMMAND write_parSimulation
{
	BLOCK function_block_1;
	INDEX 34;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parSimulationStatus,
			func1_AI_simulate_value, 
			func1_AI_simulation_enabled
		}
		REPLY
		{
		}
	}
}

VARIABLE parPAAIOutStatus
{
	LABEL "|en|out status|de|Out Status|fr|Statut Sortie|es|Out Status|it|Stato Uscita";
	CLASS CONTAINED;
	HANDLING IF (Hnd000 && Hnd003) { READ&WRITE; } ELSE { READ; }				
	TYPE UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE 128;
	}
}

COMMAND read_parPAAIOutStatus
{
	BLOCK function_block_1;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_AI_out_value, 
			parPAAIOutStatus
		}
	}
}

COMMAND write_parPAAIOutStatus
{
	BLOCK function_block_1;
	INDEX 10;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_AI_out_value, 
			parPAAIOutStatus
		}
		REPLY
		{
		}
	}
}

VARIABLE parDisplayValue
{
	LABEL "Display Value";
	CLASS DYNAMIC;
	HANDLING READ;
	VALIDITY IF (Val000) { TRUE; } ELSE { FALSE; }
	TYPE FLOAT
	{
		DEFAULT_VALUE 0;
	}
}

VARIABLE parDisplayStatus
{
	LABEL "Display Status";
	CLASS DYNAMIC;
	HANDLING READ;
	VALIDITY IF (Val000) { TRUE; } ELSE { FALSE; }
	TYPE UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE 0;
	}
}

COMMAND read_parDisplayInfo
{
	BLOCK physical_block;
	INDEX 46;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parDisplayValue, 
			parDisplayStatus,
			dummyInteger	
		}
	}
}

trans1_calibration_type_offline LIKE VARIABLE trans1_calibration_type {
	REDEFINE LABEL "|en|cal. type|de|Abgleichart|fr|Type calibration|es|Abgleichart|it|tipo di cal.|nl|afregelkeuze";
	REDEFINE POST_EDIT_ACTIONS {
		meth_pe_trans1_calibration_type_offline
	}
}

write_trans1_calibration_type_offline LIKE COMMAND write_trans1_calibration_type {
	REDEFINE TRANSACTION { REQUEST { trans1_calibration_type_offline } }
}

read_trans1_calibration_type_offline LIKE COMMAND read_trans1_calibration_type {
	REDEFINE TRANSACTION { REPLY { trans1_calibration_type_offline } }
}


trans1_cal_point_hi_offline LIKE VARIABLE trans1_cal_point_hi {
	REDEFINE LABEL "|en|cap. full|de|Kap. Vollabgl.|fr|Capacit plein|es|Kap. Vollabgl.|it|cap. di pieno|nl|volcapaciteit";
	REDEFINE HANDLING IF (Hnd000 && Hnd002) { READ&WRITE; } ELSE { READ; }
}

write_trans1_cal_point_hi_offline LIKE COMMAND write_trans1_cal_point_hi {
	REDEFINE TRANSACTION { REQUEST { trans1_cal_point_hi_offline } }
}

read_trans1_cal_point_hi_offline LIKE COMMAND read_trans1_cal_point_hi {
	REDEFINE TRANSACTION { REPLY { trans1_cal_point_hi_offline } }
}


trans1_cal_point_lo_offline LIKE VARIABLE trans1_cal_point_lo {
	REDEFINE LABEL "|en|cap. empty|de|Kap. Leerabgl.|fr|Capacit vide|es|Kap. Leerabgl.|it|cap. di vuoto|nl|leegcapaciteit";
	REDEFINE HANDLING IF (Hnd000 && Hnd002) { READ&WRITE; } ELSE { READ; }
}

write_trans1_cal_point_lo_offline LIKE COMMAND write_trans1_cal_point_lo {
	REDEFINE TRANSACTION { REQUEST { trans1_cal_point_lo_offline } }
}

read_trans1_cal_point_lo_offline LIKE COMMAND read_trans1_cal_point_lo {
	REDEFINE TRANSACTION { REPLY { trans1_cal_point_lo_offline } }
}


trans1_level_lo_offline LIKE VARIABLE trans1_level_lo {
	REDEFINE LABEL "|en|value empty|de|Wert Leerabgl.|fr|Valeur cal. vide|es|Wert Leerabgl.|it|val. di vuoto|nl|leegwaarde";
	REDEFINE HANDLING IF (Hnd000 && Hnd002) { READ&WRITE; } ELSE { READ; }
}

write_trans1_level_lo_offline LIKE COMMAND write_trans1_level_lo {
	REDEFINE TRANSACTION { REQUEST { trans1_level_lo_offline } }
}

read_trans1_level_lo_offline LIKE COMMAND read_trans1_level_lo {
	REDEFINE TRANSACTION { REPLY { trans1_level_lo_offline } }
}


trans1_level_hi_offline LIKE VARIABLE trans1_level_hi {
	REDEFINE LABEL "|en|value full|de|Wert Vollabgl.|fr|Valeur cal.plein|es|Wert Vollabgl.|it|al. di pieno|nl|volwaarde";
	REDEFINE HANDLING IF (Hnd000 && Hnd002) { READ&WRITE; } ELSE { READ; }
}

write_trans1_level_hi_offline LIKE COMMAND write_trans1_level_hi {
	REDEFINE TRANSACTION { REQUEST { trans1_level_hi_offline } }
}

read_trans1_level_hi_offline LIKE COMMAND read_trans1_level_hi {
	REDEFINE TRANSACTION { REPLY { trans1_level_hi_offline } }
}


parBargraphScaleMin_offline LIKE VARIABLE parBargraphScaleMin {
	REDEFINE HANDLING IF (Hnd000 && Hnd002) { READ&WRITE; } ELSE { READ; }
}

write_parBargraphScaleMin_offline LIKE COMMAND write_parBargraphScaleMin {
	REDEFINE TRANSACTION { REQUEST { parBargraphScaleMin_offline } }
}

read_parBargraphScaleMin_offline LIKE COMMAND read_parBargraphScaleMin {
	REDEFINE TRANSACTION { REPLY { parBargraphScaleMin_offline } }
}


parBargraphScaleMax_offline LIKE VARIABLE parBargraphScaleMax {
	REDEFINE HANDLING IF (Hnd000 && Hnd002) { READ&WRITE; } ELSE { READ; }
}

write_parBargraphScaleMax_offline LIKE COMMAND write_parBargraphScaleMax {
	REDEFINE TRANSACTION { REQUEST { parBargraphScaleMax_offline } }
}

read_parBargraphScaleMax_offline LIKE COMMAND read_parBargraphScaleMax {
	REDEFINE TRANSACTION { REPLY { parBargraphScaleMax_offline } }
}

/** ----------------------------------------------------------------
  *    Title/Dummy variables
  * ----------------------------------------------------------------
  */

VARIABLE TitleCalibration {
	LABEL 	"|en|Calibration Configuration|de|Konfiguration Grundabgleich";
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleCalibration] }
        }	
}

VARIABLE TitleExtendedCalibration {
	LABEL 	"|en|Extended Calibration Configuration|de|Konfiguration Erweit. Abgleich";
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleExtendedCalibration] }
        }	
}

VARIABLE TitleProfibusParameter {
	LABEL 	"|en|Profibus Parameter Configuration|de|Konfiguration Profibus Parameter";
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleProfibusParameter] }
        }	
}

VARIABLE TitleSystemParameter {
	LABEL 	"|en|System Parameter Configuration|de|Konfiguration System Parameter";
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleSystemParameter] }
        }	
}

VARIABLE TitleSecuritySettings {
	LABEL 	"|en|Security Settings Configuration|de|Konfiguration Sicherheitseinstellungen";
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleSecuritySettings] }
        }	
}

VARIABLE  TitleDiagnosticsReset {
	LABEL 	[LabTitleDiagnosticsReset] ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleDiagnosticsReset] }
        }
} 

VARIABLE TitleSimulationEnabled {
	LABEL 	[LabTitleSimulationEnabled] ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleSimulationEnabled] }
        }	
}

VARIABLE TitleService__configuration {
	LABEL 	"|en|Service Configuration|de|Konfiguration Service" ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleService] }
        }	
}

VARIABLE Title_parClearLastError {
	LABEL 	"|en|clear last error|de|Lsche let.Fehl.|fr|Eff. der. dfaut|es|Lsche let.Fehl.|it|canc.ult. err.|nl|wis laatste fout" ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleDiagnostics] }
        }	
}

VARIABLE capacity_low_value {
	LABEL "capacity low value";
	CLASS LOCAL;
	CONSTANT_UNIT "pF";
	HANDLING READ;
	TYPE FLOAT {
		DEFAULT_VALUE 0;
	}
}

VARIABLE capacity_high_value {
	LABEL "capacity high value";
	CLASS LOCAL;
	CONSTANT_UNIT "pF";
	HANDLING READ;
	TYPE FLOAT {
		DEFAULT_VALUE 2100;
	}
}

VARIABLE dummyInteger
{
	LABEL "dummyInteger";
	CLASS LOCAL;
	HANDLING READ;
	TYPE UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE 0;
	}
}

/** ----------------------------------------------------------------
  *    Unit relations
  * ----------------------------------------------------------------
  */

COLLECTION OF VARIABLE collectionMapping
{
        MEMBERS
        {
                parTagEH, phys_tag_desc, "|en|tag no.|de|Messstelle|fr|N Repere|es|Messstelle|it|Tag n|nl|tag nummer";
        	trans1_primary_value_unit, trans1_primary_value_unit, "|en|unit PV|de|Einheit Messwert|fr|Unit val. mes.|es|Einheit Messwert|it|unit val. mis.";
        	func1_AI_pv_upper_range_value, func1_AI_pv_upper_range_value, "|en|PV Scale max|de|PV Scale max|fr|Max. chelle PV|es|PV Scale max|it|max. scala PV|nl|PV schaal max.";       	
        	trans1_level_unit, trans1_level_unit, "|en|unit level|de|Einh. Fllstand|fr|Unit niveau|es|Einh. Fllstand|it|unit livello|nl|niveau eenheid";        	        	
        	trans1_calibration_type, trans1_calibration_type, "|en|cal. type|de|Abgleichart|fr|Type calibration|es|Abgleichart|it|tipo di cal.|nl|afregelkeuze";
        	trans1_lin_type, trans1_lin_type, "|en|position vessel|de|Einbaulage Tank|fr|position cuve|es|Einbaulage Tank|it|posiz. serbatoio";
        	trans1_cal_point_lo, trans1_cal_point_lo, "|en|cap. empty|de|Kap. Leerabgl.|fr|Capacit vide|es|Kap. Leerabgl.|it|cap. di vuoto|nl|leegcapaciteit";
        	trans1_level_lo, trans1_level_lo, "|en|value empty|de|Wert Leerabgl.|fr|Valeur cal. vide|es|Wert Leerabgl.|it|val. di vuoto|nl|leegwaarde";
        	trans1_cal_point_hi, trans1_cal_point_hi, "|en|cap. full|de|Kap. Vollabgl.|fr|Capacit plein|es|Kap. Vollabgl.|it|cap. di pieno|nl|volcapaciteit";
        	trans1_level_hi, trans1_level_hi, "|en|value full|de|Wert Vollabgl.|fr|Valeur cal.plein|es|Wert Vollabgl.|it|al. di pieno|nl|volwaarde";
        	func1_AI_hi_hi_lim, func1_AI_hi_hi_lim, "|en|upper limit 2|de|Obere Grenze 2|fr|Limite haute 2|es|Obere Grenze 2|it|limite sup. 2|nl|bovengrens 2";
        	func1_AI_hi_lim, func1_AI_hi_lim, "|en|upper limit 1|de|Obere Grenze 1|fr|Limite haute 1|es|Obere Grenze 1|it|limite sup. 1|nl|bovengrens 1"; 
        	func1_AI_lo_lo_lim, func1_AI_lo_lo_lim, "|en|lower limit 2|de|Untere Grenze 2|fr|Limite basse 2|es|Untere Grenze 2|it|limite infer. 2|nl|ondergrens 2";
        	func1_AI_lo_lim, func1_AI_lo_lim, "|en|lower limit 1|de|Untere Grenze 1|fr|Limite basse 1|es|Untere Grenze 1|it|limite infer. 1|nl|ondergrens 1";
        	func1_AI_alarm_hys, func1_AI_alarm_hys, "|en|hysteresis|de|Hysterese|fr|Hysteresis|es|Hysterese|it|isteresi|nl|hysterese";
        	func1_AI_hi_hi_alm_state, func1_AI_hi_hi_alm_state, "|en|upper alarm 2|de|Alarm voll 2|fr|Alarme haute 2|es|Alarm voll 2|it|allarme sup. 2|nl|hoogalarm 2";
        	func1_AI_hi_alm_state, func1_AI_hi_alm_state, "|en|upper alarm 1|de|Alarm voll 1|fr|Alarme haute 1|es|Alarm voll 1|it|allarme sup. 1|nl|hoogalarm 1";
        	func1_AI_lo_lo_alm_state, func1_AI_lo_lo_alm_state, "|en|lower alarm 2|de|Alarm leer 2|fr|Alarme basse 2|es|Alarm leer 2|it|allarme inf. 2|nl|laagalarm 2";
        	func1_AI_lo_alm_state, func1_AI_lo_alm_state, "|en|lower alarm 1|de|Alarm leer 1|fr|Alarme basse 1|es|Alarm leer 1|it|allarme inf. 1|nl|laagalarm 1";
        	func1_AI_pv_lower_range_value, func1_AI_pv_lower_range_value, "|en|PV Scale min|de|PV Scale min|fr|Min. chelle PV|es|PV Scale min|it|min. scala PV|nl|PV schaal min.";
        	func1_AI_out_lower_range_value, func1_AI_out_lower_range_value, "|en|OUT Scale min|de|OUT Scale min|fr|Min. chelle OUT|es|OUT Scale min|it|fuori scala min|nl|uit schaal min.";
        	func1_AI_out_upper_range_value, func1_AI_out_upper_range_value, "|en|OUT Scale max|de|OUT Scale max|fr|Max. chelle OUT|es|OUT Scale max|it|fuori scala max|nl|uit schaal max.";
        	phys_ident_number, phys_ident_number, "|en|ident number|de|Ident Number|fr|No Identificat|es|Ident Number|it|Numero Ident";
        	func1_AI_target_mode, func1_AI_target_mode, "|en|Target Mode|de|Target Mode|fr|Mode Target|es|Target Mode|it|modo terget|nl|doelkeuze";
        	func1_AI_out_unit, func1_AI_out_unit, "|en|out unit|de|Out Einheit|fr|Unit OUT|es|Einh. OUT Wert|it|unit uscita|nl|uit eenheid";
        	func1_AI_out_value, func1_AI_out_value, "|en|out value|de|Out Wert|fr|Valeure de Sort.|es|Out Wert|it|Valore Uscita";
        	trans1_primary_value_value, trans1_primary_value_value, "|en|measured value|de|Messwert|fr|Valeur de mesure|es|Messwert|it|Valore di misura|nl|gemeten waarde";
        	phys_device_id, phys_device_id, "|en|device ID number";
        	func1_AI_pv_ftime, func1_AI_pv_ftime, "|en|integration time|de|Integrationszeit|fr|Temps d'int.|es|Integrationszeit|it|tempo d'integraz|nl|integratietijd";
        	phys_descriptor, phys_descriptor, "|en|description|de|Beschreibung|fr|Designation Proc|es|Beschreibung|it|Descriptor|nl|beschrijving";
        	phys_software_rev, phys_software_rev, "|en|software version|de|Software Version|fr|Version Software|es|Software Version|it|Vers. Software|nl|software versie";
        	phys_hardware_rev, phys_hardware_rev, "|en|hardware version|de|Hardware Version|fr|Version Hardware|es|Hardware Version|it|Vers. Hardware|nl|hardware versie";
        	phys_device_ser_num, phys_device_ser_num, "|en|serial no.|de|Seriennummer|fr|Numro de srie|es|Seriennummer|it|Num. di serie|nl|serienummer";
        	trans1_min_sensor_value, trans1_min_sensor_value, "|en|min. meas. value|de|Min. Messwert|fr|Val. min. mesur.|es|Min. Messwert|it|min. val. misur.|nl|min. meetwaarde";
        	trans1_max_sensor_value, trans1_max_sensor_value, "|en|max. meas. value|de|Max. Messwert|fr|Val. max. mesur.|es|Max. Messwert|it|max. val. misur.|nl|max. meetwaarde";
        	trans1_temperature, trans1_temperature, "|en|electronictemp.|de|Elektroniktemp.|fr|Temperature el.|es|Elektroniktemp.|it|Temperatura el.";
        	trans1_temperature_unit, trans1_temperature_unit, "|en|unit temp.|de|Einheit Temp.|fr|Unit temp.|es|Einheit Temp.|it|unit temp.|nl|temp. eenheid";
        	trans1_min_temperature, trans1_min_temperature, "|en|min. temp.|de|Min. Temp.|fr|Temprature min.|es|Min. Temp.|it|temp. min.|nl|min. temperatuur";
        	trans1_max_temperature, trans1_max_temperature, "|en|max. meas. temp|de|Max. Temp.|fr|Temp. max mesur.|es|Max. Temp.|it|max picco temp.|nl|max.gemet.temp.";
        	trans1_sensor_value, trans1_sensor_value, "|en|measured cap.|de|Messkapazitt|fr|capacit mesure|es|Messkapazitt|it|capacit di mis.";
        	func1_AI_simulation_enabled, func1_AI_simulation_enabled, "|en|simulation|de|Simulation|fr|Simulation|es|Simulation|it|simulazione|nl|simulatie";
        	func1_AI_simulate_value, func1_AI_simulate_value, "|en|sim. value|de|Sim. Messwert|fr|Simul. Mesure|es|Sim. Messwert|it|Sim. Valore";
        }
}

/** ----------------------------------------------------------------
  *    E+H Specific online menus
  * ----------------------------------------------------------------
  */

MENU Page_display_value
{
	LABEL	"|en|Measured values|de|Messwerte";
	ITEMS
	{
		Val_trans1_primary_value_value,
		BarVal_measured_cap,
		Group_measured_values
	}
}

MENU BarVal_measured_value
{
	LABEL	"|en|measured value|de|Messwert|fr|Valeur de mesure|es|Messwert|it|Valore di misura|nl|gemeten waarde";
	ITEMS
	{
		trans1_primary_value_value (READ_ONLY),
		func1_AI_pv_lower_range_value	(READ_ONLY),
		func1_AI_pv_upper_range_value	(READ_ONLY)
	}
}

MENU BarVal_measured_cap
{
	LABEL	"|en|measured cap.|de|Messkapazitt|fr|capacit mesure|es|Messkapazitt|it|capacit di mis.";
	ITEMS
	{
		trans1_sensor_value (READ_ONLY),
		capacity_low_value,		//		trans1_min_sensor_value (READ_ONLY),
		capacity_high_value		//		trans1_max_sensor_value (READ_ONLY)
	}	
}

MENU Group_measured_values
{
	LABEL "";
	ITEMS
	{
		Val_parDisplayValue,
		Val_trans1_level,
		Val_trans1_sensor_value,
		SEPARATOR,
		Val_parDisplayStatus,
		Val_trans1_temperature,
		Val_parActualError,
	}
}

MENU Val_parDisplayValue
{
	LABEL "|en|Display Value";
	ITEMS 
	{
		parDisplayValue
	}	
}

MENU Val_parDisplayStatus
{
	LABEL "|en|Display Status";
	ITEMS 
	{
		parDisplayStatus
	}	
}

MENU Val_trans1_primary_value_value
{
	LABEL "|en|measured value|de|Messwert|fr|Valeur de mesure|es|Messwert|it|Valore di misura|nl|gemeten waarde";
	ITEMS
	{
		trans1_primary_value_value
	}
}

MENU Val_trans1_level
{
	LABEL "|en|measured level|de|gemess. Fllst.|fr|Niveau mesur|es|gemess. Fllst.|it|Livello mis.|nl|gemeten niveau";
	ITEMS
	{
		trans1_level
	}
}

MENU Val_trans1_sensor_value
{
	LABEL "|en|measured cap.|de|Messkapazitt|fr|capacit mesure|es|Messkapazitt|it|capacit di mis.";
	ITEMS
	{
		trans1_sensor_value
	}
}

MENU Val_trans1_temperature
{
	LABEL "|en|electronictemp.|de|Elektroniktemp.|fr|Temperature el.|es|Elektroniktemp.|it|Temperatura el.";
	ITEMS
	{
		trans1_temperature
	}
}

MENU Val_parActualError
{
	LABEL "|en|present error|de|aktueller Fehler|fr|Dfaut actuel|es|aktueller Fehler|it|errore attuale|nl|actuele fout";
	ITEMS
	{
		parActualError
	}
}

MENU Val_parLastError
{
	LABEL "|en|previous error|de|letzter Fehler|fr|Dernier dfaut|es|letzter Fehler|it|ultimo errore|nl|vorige fout";
	ITEMS
	{
		parLastError
	}
}

OnlineDialog_security_settings LIKE MENU Tab_s_security_settings {
}

OnlineDialog_extended_calibration LIKE MENU Tab_s_extended_calibration {
}

OnlineDialog_system_parameter LIKE MENU Tab_s_system_parameter {
}

MENU   OnlineDialog_Reset {
	LABEL 	[Online_Reset] ;
	ITEMS { 
		Page_Reset_1_1
	} 
}

MENU   Page_Reset_1_1 {
	LABEL 	[Online_Reset_1_1] ;
	ITEMS { 
		parReset
	} 
}

MENU   OnlineDialog_SetUnitToBus {
	LABEL 	[Online_SetUnitToBus] ;
	ITEMS { 
		Page_SetUnitToBus_1_1
	} 
}

MENU   Page_SetUnitToBus_1_1 {
	LABEL 	[Online_SetUnitToBus] ;
	ITEMS { 
		setUnitToBus
	} 
}

MENU   OnlineDialog_Simulation {
	LABEL 	[Online_Simulation] ;
	ITEMS { 
		Page_simulation_input_func1,
		Page_simulation_output_func1,
		Page_simulation_devicespecific
	} 
}

MENU	Page_simulation_devicespecific {
	LABEL "|en|Simulation (manufacturer specific)|de|Simulation (herstellerspezifisch)";
	ITEMS {
		collectionMapping.func1_AI_simulation_enabled,
		collectionMapping.func1_AI_simulate_value,
		parSimulationStatus		
	}	
}

MENU	OnlineDialog_Adjust_BasicSetup {
	LABEL [menu_table_abgleich];
	ITEMS {
		Page_Adjust_BasicSetup_step1,
		Page_Adjust_BasicSetup_step2,
		Page_Adjust_BasicSetup_step3
	}
}

MENU	Page_Adjust_BasicSetup_step1 {
	LABEL "|en|Step 1/3|de|Schritt 1/3";
	ITEMS {
		collectionMapping.trans1_primary_value_unit,
		collectionMapping.trans1_level_unit,
		collectionMapping.trans1_calibration_type,
		collectionMapping.trans1_lin_type		
	}
}

MENU	Page_Adjust_BasicSetup_step2 {
	LABEL "|en|Step 2/3|de|Schritt 2/3";
	ITEMS {
		collectionMapping.trans1_sensor_value,
		trans1_level,
		collectionMapping.trans1_primary_value_value,
		SEPARATOR,
		collectionMapping.trans1_cal_point_lo,
		collectionMapping.trans1_level_lo,
		parBargraphScaleMin,
		meth_transfer_calibration_empty // method_set
	}
}

MENU	Page_Adjust_BasicSetup_step3 {
	LABEL "|en|Step 3/3|de|Schritt 3/3";
	ITEMS {
		collectionMapping.trans1_sensor_value,
		trans1_level,
		collectionMapping.trans1_primary_value_value,
		SEPARATOR,
		collectionMapping.trans1_cal_point_hi,
		collectionMapping.trans1_level_hi,
		parBargraphScaleMax,
		meth_transfer_calibration_full // method_set
	}
}

MENU OnlineDialog_profibus_parameter
{
	LABEL		[menu_table_profibus_parameter];
	ITEMS {
		parPADeviceBusAddress,
		collectionMapping.phys_ident_number,
		parPASelectMainValue,
		parPASetUnitToBus,
		collectionMapping.func1_AI_target_mode,
		collectionMapping.func1_AI_out_unit,
		collectionMapping.func1_AI_out_value,
		parPAAIOutStatus		
	}
}

MENU   OnlineDialog_Adjust_Service {
	LABEL 	"Service" ;
	ITEMS {
		collectionMapping.trans1_min_sensor_value (READ_ONLY),
		meth_reset_trans1_min_sensor_value,
		collectionMapping.trans1_max_sensor_value (READ_ONLY),
		meth_reset_trans1_max_sensor_value,
		collectionMapping.trans1_temperature,
		collectionMapping.trans1_temperature_unit,
		collectionMapping.trans1_min_temperature (READ_ONLY),
		meth_reset_min_temperature,
		collectionMapping.trans1_max_temperature (READ_ONLY),		
		meth_reset_max_temperature,
		parSystemstartsCounter,
		parActualError,
		parLastError,
		parClearLastError,
		parWriteLocking
	} 
}


MENU   OnlineDialog_write_locking {
	LABEL 	[phys_write_locking] ;
	ITEMS { 
		page_phys_write_locking_user
	} 
}

MENU   page_phys_write_locking_user {
	LABEL 	[phys_write_locking_user] ;
	ITEMS { 
		parShowAccess,
		parWriteLocking,
		method_set
	}
}

/** ----------------------------------------------------------------
  *    E+H Specific offline menus
  * ----------------------------------------------------------------
  */

MENU Tab_s_EH_Std_Matrix
{
	LABEL		[menu_table_EH_Std_Matrix];
	ITEMS
	{		
		Tab_s_measured_values,
		Tab_s_abgleich,
		Tab_s_extended_calibration,
		Tab_s_profibus_parameter,
		Tab_s_system_parameter,
		Tab_s_security_settings,
		Tab_s_simulation,
		Tab_s_service
	}
}

MENU Tab_s_measured_values
{
	LABEL "Measured Values|de|Messwert";
	ITEMS {
		collectionMapping.trans1_primary_value_value (READ_ONLY),
		trans1_level (READ_ONLY),
		collectionMapping.trans1_sensor_value (READ_ONLY)
	}
}

MENU Tab_s_abgleich
{
	LABEL		[menu_table_abgleich];
	ACCESS OFFLINE;
	ITEMS
	{
		TitleCalibration,
		collectionMapping.trans1_primary_value_unit,
		collectionMapping.trans1_level_unit,
		trans1_calibration_type_offline,
		collectionMapping.trans1_lin_type,
		trans1_cal_point_lo_offline,
		trans1_level_lo_offline,
		parBargraphScaleMin_offline,
		trans1_cal_point_hi_offline,
		trans1_level_hi_offline,
		parBargraphScaleMax_offline
	}
}

MENU Tab_s_security_settings
{
	LABEL		[menu_table_security_settings];
	ITEMS
	{
		TitleSecuritySettings,
		collectionMapping.func1_AI_hi_hi_lim,
		collectionMapping.func1_AI_hi_lim,
		collectionMapping.func1_AI_lo_lim,
		collectionMapping.func1_AI_lo_lo_lim,
		collectionMapping.func1_AI_alarm_hys,
		collectionMapping.func1_AI_hi_hi_alm_state,
		collectionMapping.func1_AI_hi_alm_state,
		collectionMapping.func1_AI_lo_alm_state,
		collectionMapping.func1_AI_lo_lo_alm_state
	}
}

MENU Tab_s_extended_calibration
{
	LABEL		[menu_table_extended_calibration];
	ITEMS
	{
		TitleExtendedCalibration,
		collectionMapping.func1_AI_pv_ftime,
		collectionMapping.func1_AI_pv_lower_range_value,
		collectionMapping.func1_AI_pv_upper_range_value,
		collectionMapping.func1_AI_out_lower_range_value,
		collectionMapping.func1_AI_out_upper_range_value
	}
}

MENU Tab_s_profibus_parameter
{
	LABEL		[menu_table_profibus_parameter];
	ACCESS OFFLINE;
	ITEMS
	{
		TitleProfibusParameter,
		parPADeviceBusAddress,
		collectionMapping.phys_ident_number,
		parPASelectMainValue,
		parPASetUnitToBus_offline,
		collectionMapping.func1_AI_target_mode,
		collectionMapping.func1_AI_out_unit,
		collectionMapping.func1_AI_out_value,
		parPAAIOutStatus		
	}
}

MENU Tab_s_system_parameter
{
	LABEL		[menu_table_system_parameter];
	ITEMS
	{
		TitleSystemParameter,
		collectionMapping.parTagEH,
		collectionMapping.phys_descriptor,
		collectionMapping.phys_software_rev,
		collectionMapping.phys_hardware_rev,
		collectionMapping.phys_device_id,
		collectionMapping.phys_device_ser_num		
	}
}

MENU Tab_s_simulation
{
	LABEL		[menu_table_simulation];
	ITEMS
	{
		TitleSimulationEnabled,
		collectionMapping.func1_AI_simulation_enabled (READ_ONLY),
		collectionMapping.func1_AI_simulate_value (READ_ONLY),
		parSimulationStatus (READ_ONLY)
	}
}

MENU Tab_s_service
{
	LABEL		[menu_table_service];
	ITEMS
	{
		TitleService__configuration,
		collectionMapping.trans1_min_sensor_value (READ_ONLY),
		collectionMapping.trans1_max_sensor_value (READ_ONLY),
		collectionMapping.trans1_temperature,
		collectionMapping.trans1_temperature_unit,
		collectionMapping.trans1_min_temperature (READ_ONLY),
		collectionMapping.trans1_max_temperature (READ_ONLY),
		parSystemstartsCounter,
		parActualError,
		parLastError,
		parClearLastError,
		TitleDiagnosticsReset,
		parWriteLocking (READ_ONLY)
	}
}

MENU Tab_s_PA_Profil
{
	LABEL	"Capacitive Level Measurement|de|Kapazitive Fllstandsmesseinrichtung";
	ITEMS
	{
		Tab_s_ident,
		Tab_s_input,
		Tab_s_output,
		Tab_s_certificates
	}			
}

/** ----------------------------------------------------------------
  *    Methods
  * ----------------------------------------------------------------
  */

METHOD updateParShowAccess
{
        DEFINITION
        {
                switch (parWriteLocking)
                {
                        case 2457:
                        {
                                parShowAccess = 4;
                        }; break;
                        default:
                        {
                                parShowAccess = 0;
                        }; break;
                }
        }
}

METHOD setUnitToBus
{
        LABEL "|en|set unit to bus|de|Setze Einh. Out";
        DEFINITION
        {
                WriteCommand(write_parPASetUnitToBus);
        }
}

METHOD uploadVariablesPreWriteActions
{
        LABEL "Download of the Operation Code before uploading the variables" ;
        DEFINITION
        {
                ReadCommand(read_parWriteLocking);
                if (parWriteLocking != 2457)
                {
                        ACKNOWLEDGE("|en|No variables have been uploaded|de|Es wurde keine Variablen geschrieben");
                }
        }
}

METHOD downloadVariablesPreReadActions
{
        LABEL "downloadVariablesPreReadActions" ;
        DEFINITION
        {
                ReadCommand(read_parWriteLocking);
        }
}

METHOD meth_reset_trans1_min_sensor_value {
	LABEL "|en|Reset min. meas. value|de|Min. Messwert rcksetzen";
        DEFINITION
        {
                WriteCommand(write_trans1_min_sensor_value);
        }
}

METHOD meth_reset_trans1_max_sensor_value {
	LABEL "|en|Reset max. meas. value|de|Max. Messwert rcksetzen";
        DEFINITION
        {
                WriteCommand(write_trans1_max_sensor_value);
        }
}	

METHOD meth_reset_min_temperature {
	LABEL "|en|Reset min. temp.|de|Min. Temp. rcksetzen";
        DEFINITION
        {
                WriteCommand(write_trans1_min_temperature);
        }
}	

METHOD meth_reset_max_temperature {
	LABEL "|en|Reset max. temp.|de|Max. Temp. rcksetzen";
        DEFINITION
        {
                WriteCommand(write_trans1_max_temperature);
        }
}

METHOD meth_set_unit_to_bus {
	DEFINITION
	{
		if (parPASetUnitToBus_offline == 1) {
			func1_AI_out_unit = trans1_primary_value_unit;
			func1_AI_out_lower_range_value = func1_AI_pv_lower_range_value;
			func1_AI_out_upper_range_value = func1_AI_pv_upper_range_value;
			parPASetUnitToBus_offline = 0;
		}
	}
}

METHOD meth_pe_trans1_calibration_type_offline {
	DEFINITION
	{
		if (trans1_calibration_type_offline == 1)
		{
			ACKNOWLEDGE("|en|Online Calibration not possible in Offlinetable. See Menu Device, Calibration.|de|Online Abgleich in Offlinetabelle nicht mglich. Siehe Men Gert, Grundabgleich.");
		}
	}
}

METHOD meth_transfer_calibration_empty {
	LABEL "|en|Transfer|de|bertragen";
	DEFINITION
	{		
		if ( Hnd001 )
		{
			WriteCommand(write_trans1_cal_point_lo);
		}
		WriteCommand(write_trans1_level_lo);
		WriteCommand(write_parBargraphScaleMin);
	}
}

METHOD meth_transfer_calibration_full {
	LABEL "|en|Transfer|de|bertragen";
	DEFINITION
	{		
		if ( Hnd001 )
		{
			WriteCommand(write_trans1_cal_point_hi);
		}
		WriteCommand(write_trans1_level_hi);
		WriteCommand(write_parBargraphScaleMax);
	}
}