// Modified by J. Messer, 2003.06.18: removed the "SIPAST" include.
/*---------------------------------------------------------------------------------------------*/
/*	Copyright (C) Siemens AG (1998). All Rights Reserved	*/
/*	Product:		SIMATIC PDM				*/
/*                                                          					*/
/*	Device:		LEVEL deviced for PROFIBUS PA		*/
/*					(Echo, Hydrostatic)	*/
/*	Description:	Device Description			*/
/*	Dictionary:		SIPADC01.dct			*/
/*                                                          			*/
/*  $Revision:   1.6  $						*/
/*  $Date:   Mar 13 2001  $				*/
/*---------------------------------------------------------------------------------------------*/


MANUFACTURER	252,
DEVICE_TYPE		1,
DEVICE_REVISION 0x0200,
DD_REVISION		1

#include "SIPAST_Macros_300.inc"

// #include "SIPAST.inc"		// Commented by J. Messer, 2003.06.18

#include "SIPAST_CommError.inc"

#define YT1_LABEL		[func_out_value]
#define YT1_HELP		[func_ai_out_value_help]
#define YT1_VALUE		func1_AI_out_value
#define	YT1_LRV		func1_AI_out_lower_range_value
#define YT1_URV		func1_AI_out_upper_range_value
#include "SI_YT.inc"



///////////////////////////////////////////////////////////////
// Device Type name for help generation

VARIABLE DEVICE_TYPE_Name
{
	LABEL "DEVICE_TYPE_Name" ;
	TYPE ASCII(64)
	{
		DEFAULT_VALUE	"Profile 3 Level"
						"|de|Profil 3 Fllstand"
						"|fr|Profile 3 mesure de niveau"
						"|sp|Perfil 3 convertidor de medicin de nivel"
						"|it|Profilo 3 trasduttore di livello" ;
	}

#ifdef _V521_
	CLASS LOCAL & TEMPORARY ;
#else
	CLASS LOCAL ;
#endif

}



/***********************************************************************/

#define	FLOAT_MIN	-3.4E+38
#define	FLOAT_MAX	 3.4E+38

#define		LEVEL_HYDRO		\
((trans1_blk_parent_class == 4) && (trans1_blk_class == 1))

#define		LEVEL_ECHO		\
((trans1_blk_parent_class == 4) && (trans1_blk_class == 2))


#define		VALID_LEVEL_HYDRO	\
IF (LEVEL_HYDRO)			\
{					\
	TRUE;				\
}					\
ELSE {					\
	FALSE;				\
}

#define		VALID_LEVEL_ECHO	\
IF (LEVEL_ECHO)			\
{					\
	TRUE;				\
}					\
ELSE {					\
	FALSE;				\
}


#define _TRANS1_LEVEL 
#include "Trans1.inc"





/**************************************************************************************************/
/*    Physical Block								  */
/**************************************************************************************************/

#define DEVICE_TYPE "Level" "|de|Fllstand" "|fr|Niveau" "|sp|Nivel" "|sp|Livello di riempimento"
#define OPT_PHYS_IDENT_NUMBER_MANUFACTURER

#include "SIPASTPB_300.inc"




/*************************************************************************************************/
/*    Function Block                                                   				  */
/*************************************************************************************************/


#define DEFAULT_UPPER_VAL	DEFAULT_VALUE 10 ;

#define DEFAULT_LOWER_VAL	DEFAULT_VALUE 0 ;

#define FUNC1_TITLE	[trans_blk_parent_class_LEVEL]

#define FUNC1_DEFAULT_UNIT		1010

#define FUNC1_PV	trans1_level

#include "SIPASTAI_300.inc"



// --- common dialogs and menues -----------------------------------------------------

#include "SIPAST_CommonDlgs.inc"

#include "SI_HlpM.inc"
#include "SI_FileM.inc"
#include "SI_ViewM.inc"
#include "SI_OptM.inc"




/*------------------------------------------------------------------------------------------------------------------------------------*/
/*    Transducer Block: Level Transmitter							   */
/*-------------------------------------------------------------------------------------------------------------------------------------*/

VARIABLE trans1_primary_value_value
{
	LABEL		[trans_primary_value_value];
	HELP		[trans_primary_value_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE trans1_primary_value_status
{
	LABEL		[trans_primary_value_status];
	HELP		[trans_primary_value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
/* bad */
		{	0,	[bad_0]			},	
		{	1,	[bad_1]			},
		{	2,	[bad_2]			},
		{	3,	[bad_3]			},
		{	4,	[bad_4]			},
		{	5,	[bad_5]			},
		{	6,	[bad_6]			},
		{	7,	[bad_7]			},
		{	8,	[bad_8]			},
		{	9,	[bad_9]			},
		{	10,	[bad_10]		},
		{	11,	[bad_11]		},
		{	12,	[bad_12]		},
		{	13,	[bad_13]		},
		{	14,	[bad_14]		},
		{	15,	[bad_15]		},
		{	16,	[bad_16]		},
		{	17,	[bad_17]		},
		{	18,	[bad_18]		},
		{	19,	[bad_19]		},
		{	20,	[bad_20]		},
		{	21,	[bad_21]		},
		{	22,	[bad_22]		},
		{	23,	[bad_23]		},
		{	24,	[bad_24]		},
		{	25,	[bad_25]		},
		{	26,	[bad_26]		},
		{	27,	[bad_27]		},
		{	28,	[bad_28]		},
		{	29,	[bad_29]		},
		{	30,	[bad_30]		},
		{	31,	[bad_31]		},
		{	32,	[bad_32]		},
		{	33,	[bad_33]		},
		{	34,	[bad_34]		},
		{	35,	[bad_35]		},
/* uncertain */
		{	64,	[uncertain_64]	},
		{	65,	[uncertain_65]	},
		{	66,	[uncertain_66]	},
		{	67,	[uncertain_67]	},
		{	68,	[uncertain_68]	},
		{	69,	[uncertain_69]	},
		{	70,	[uncertain_70]	},
		{	71,	[uncertain_71]	},
		{	72,	[uncertain_72]	},
		{	73,	[uncertain_73]	},
		{	74,	[uncertain_74]	},
		{	75,	[uncertain_75]	},
		{	76,	[uncertain_76]	},
		{	77,	[uncertain_77]	},
		{	78,	[uncertain_78]	},
		{	79,	[uncertain_79]	},
		{	80,	[uncertain_80]	},
		{	81,	[uncertain_81]	},
		{	82,	[uncertain_82]	},
		{	83,	[uncertain_83]	},
		{	84,	[uncertain_84]	},
		{	85,	[uncertain_85]	},
		{	86,	[uncertain_86]	},
		{	87,	[uncertain_87]	},
		{	88,	[uncertain_88]	},
		{	89,	[uncertain_89]	},
		{	90,	[uncertain_90]	},
		{	91,	[uncertain_91]	},
		{	92,	[uncertain_92]	},
		{	93,	[uncertain_93]	},
		{	94,	[uncertain_94]	},
		{	95,	[uncertain_95]	},
/* good */
		{	128,[good_128]		},
		{	129,[good_129]		},
		{	130,[good_130]		},
		{	131,[good_131]		},
		{	132,[good_132]		},
		{	133,[good_133]		},
		{	134,[good_134]		},
		{	135,[good_135]		},
		{	136,[good_136]		},
		{	137,[good_137]		},
		{	138,[good_138]		},
		{	139,[good_139]		},
		{	140,[good_140]		},
		{	141,[good_141]		},
		{	142,[good_142]		},
		{	143,[good_143]		},
		{	144,[good_144]		},
		{	145,[good_145]		},
		{	146,[good_146]		},
		{	147,[good_147]		},
		{	148,[good_148]		},
		{	149,[good_149]		},
		{	150,[good_150]		},
		{	151,[good_151]		},
		{	152,[good_152]		},
		{	153,[good_153]		},
		{	154,[good_154]		},
		{	155,[good_155]		},
		{	160,[good_160]		},
		{	161,[good_161]		},
		{	162,[good_162]		},
		{	163,[good_163]		}
	}
	HANDLING	READ;
}

VARIABLE trans1_primary_value_unit
{
   	LABEL         [trans_primary_value_unit];
   	HELP          [trans_primary_value_unit_help];
   	CLASS         CONTAINED;
   	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	FUNC1_DEFAULT_UNIT ;
/* Length */
		{ 1018,  [ft],			[ft_help]			},
		{ 1010,  [meter],			[meter_help]		},
		{ 1019,  [in],			[in_help]		},
		{ 1012,  [cm],			[cm_help]		},
		{ 1013,  [mm],			[mm_help]		},
/* Miscellaneous */
		{ 1342,  [Percent],			[Percent_help]		}
	}

   HANDLING      READ & WRITE;
}

VARIABLE trans1_level
{
	LABEL		[trans_lev_level];
	HELP		[trans_lev_level_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE trans1_level_unit
{
	LABEL	[trans_lev_level_unit];
	HELP	[trans_lev_level_unit_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	1342;
/* Length */
		{ 1018,  [ft],			[ft_help]			},
		{ 1010,  [meter],			[meter_help]		},
		{ 1019,  [in],			[in_help]		},
		{ 1012,  [cm],			[cm_help]		},
		{ 1013,  [mm],			[mm_help]		},
/* Volume */													
		{ 1048,  [gal],			[gal_help]		},
		{ 1038,  [liter],			[liter_help]		},
		{ 1049,  [ImpGal],			[ImpGal_help]		},
		{ 1034,  [CuMtr],			[CuMtr_help]		},
		{ 1051,  [bbl],			[bbl_help]		},
		{ 1050, [bush],			[bush_help]		},
		{ 1044, [CuYd],			[CuYd_help]		},
		{ 1043, [CuFt],			[CuFt_help]		},
		{ 1042, [CuIn],			[CuIn_help]		},
		{ 1052, [bbl_liq],			[bbl_liq_help]		},
		{ 1041, [hecto_liter],		[hecto_liter_help]		},
/* Miscellaneous */
		{ 1342,[Percent],			[Percent_help]		}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_sensor_value
{
   LABEL         [trans_lev_sensor_value];
   HELP          [trans_lev_sensor_value_help];
   CLASS         CONTAINED & DYNAMIC;
   TYPE          FLOAT;
   HANDLING      READ;
}

VARIABLE trans1_sensor_unit
{
   LABEL         [trans_sensor_unit];
   HELP          [trans_sensor_unit_help];
   CLASS         CONTAINED;
   	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	FUNC1_DEFAULT_UNIT ;
		{ 1018,  [ft],			[ft_help]			},
		{ 1010,  [meter],			[meter_help]		},
		{ 1130,  [PA],			[PA_help]		},
		{ 1138,  [mbar],			[mbar_help]		},
		{ 1141,  [psi],			[psi_help]		}
	}
   HANDLING      READ & WRITE;
}

VARIABLE trans1_secondary_value_1_value
{
	LABEL		[trans_secondary_value_1_value];
	HELP		[trans_secondary_value_1_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE  trans1_secondary_value_1_status
{
	LABEL		[trans_secondary_value_1_status];
	HELP		[trans_secondary_value_1_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
/* bad */
		{	0,	[bad_0]			},	
		{	1,	[bad_1]			},
		{	2,	[bad_2]			},
		{	3,	[bad_3]			},
		{	4,	[bad_4]			},
		{	5,	[bad_5]			},
		{	6,	[bad_6]			},
		{	7,	[bad_7]			},
		{	8,	[bad_8]			},
		{	9,	[bad_9]			},
		{	10,	[bad_10]		},
		{	11,	[bad_11]		},
		{	12,	[bad_12]		},
		{	13,	[bad_13]		},
		{	14,	[bad_14]		},
		{	15,	[bad_15]		},
		{	16,	[bad_16]		},
		{	17,	[bad_17]		},
		{	18,	[bad_18]		},
		{	19,	[bad_19]		},
		{	20,	[bad_20]		},
		{	21,	[bad_21]		},
		{	22,	[bad_22]		},
		{	23,	[bad_23]		},
		{	24,	[bad_24]		},
		{	25,	[bad_25]		},
		{	26,	[bad_26]		},
		{	27,	[bad_27]		},
		{	28,	[bad_28]		},
		{	29,	[bad_29]		},
		{	30,	[bad_30]		},
		{	31,	[bad_31]		},
		{	32,	[bad_32]		},
		{	33,	[bad_33]		},
		{	34,	[bad_34]		},
		{	35,	[bad_35]		},
/* uncertain */
		{	64,	[uncertain_64]	},
		{	65,	[uncertain_65]	},
		{	66,	[uncertain_66]	},
		{	67,	[uncertain_67]	},
		{	68,	[uncertain_68]	},
		{	69,	[uncertain_69]	},
		{	70,	[uncertain_70]	},
		{	71,	[uncertain_71]	},
		{	72,	[uncertain_72]	},
		{	73,	[uncertain_73]	},
		{	74,	[uncertain_74]	},
		{	75,	[uncertain_75]	},
		{	76,	[uncertain_76]	},
		{	77,	[uncertain_77]	},
		{	78,	[uncertain_78]	},
		{	79,	[uncertain_79]	},
		{	80,	[uncertain_80]	},
		{	81,	[uncertain_81]	},
		{	82,	[uncertain_82]	},
		{	83,	[uncertain_83]	},
		{	84,	[uncertain_84]	},
		{	85,	[uncertain_85]	},
		{	86,	[uncertain_86]	},
		{	87,	[uncertain_87]	},
		{	88,	[uncertain_88]	},
		{	89,	[uncertain_89]	},
		{	90,	[uncertain_90]	},
		{	91,	[uncertain_91]	},
		{	92,	[uncertain_92]	},
		{	93,	[uncertain_93]	},
		{	94,	[uncertain_94]	},
		{	95,	[uncertain_95]	},
/* good */
		{	128,[good_128]		},
		{	129,[good_129]		},
		{	130,[good_130]		},
		{	131,[good_131]		},
		{	132,[good_132]		},
		{	133,[good_133]		},
		{	134,[good_134]		},
		{	135,[good_135]		},
		{	136,[good_136]		},
		{	137,[good_137]		},
		{	138,[good_138]		},
		{	139,[good_139]		},
		{	140,[good_140]		},
		{	141,[good_141]		},
		{	142,[good_142]		},
		{	143,[good_143]		},
		{	144,[good_144]		},
		{	145,[good_145]		},
		{	146,[good_146]		},
		{	147,[good_147]		},
		{	148,[good_148]		},
		{	149,[good_149]		},
		{	150,[good_150]		},
		{	151,[good_151]		},
		{	152,[good_152]		},
		{	153,[good_153]		},
		{	154,[good_154]		},
		{	155,[good_155]		},
		{	160,[good_160]		},
		{	161,[good_161]		},
		{	162,[good_162]		},
		{	163,[good_163]		}
	}
	HANDLING	READ;
}

VARIABLE trans1_secondary_value_1_unit
{
   LABEL         [trans_secondary_value_1_unit];
   HELP          [trans_secondary_value_1_unit_help];
   CLASS        CONTAINED ;
   	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	FUNC1_DEFAULT_UNIT ;
		{ 1018,  [ft],			[ft_help]			},
		{ 1010,  [meter],			[meter_help]		},
		{ 1342,  [Percent],			[Percent_help]		}
	}

   HANDLING      READ & WRITE;
}

VARIABLE trans1_secondary_value_2_value
{
	LABEL		[trans_secondary_value_2_value];
	HELP		[trans_secondary_value_2_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE  trans1_secondary_value_2_status
{
	LABEL		[trans_secondary_value_2_status];
	HELP		[trans_secondary_value_2_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
/* bad */
		{	0,	[bad_0]			},	
		{	1,	[bad_1]			},
		{	2,	[bad_2]			},
		{	3,	[bad_3]			},
		{	4,	[bad_4]			},
		{	5,	[bad_5]			},
		{	6,	[bad_6]			},
		{	7,	[bad_7]			},
		{	8,	[bad_8]			},
		{	9,	[bad_9]			},
		{	10,	[bad_10]		},
		{	11,	[bad_11]		},
		{	12,	[bad_12]		},
		{	13,	[bad_13]		},
		{	14,	[bad_14]		},
		{	15,	[bad_15]		},
		{	16,	[bad_16]		},
		{	17,	[bad_17]		},
		{	18,	[bad_18]		},
		{	19,	[bad_19]		},
		{	20,	[bad_20]		},
		{	21,	[bad_21]		},
		{	22,	[bad_22]		},
		{	23,	[bad_23]		},
		{	24,	[bad_24]		},
		{	25,	[bad_25]		},
		{	26,	[bad_26]		},
		{	27,	[bad_27]		},
		{	28,	[bad_28]		},
		{	29,	[bad_29]		},
		{	30,	[bad_30]		},
		{	31,	[bad_31]		},
		{	32,	[bad_32]		},
		{	33,	[bad_33]		},
		{	34,	[bad_34]		},
		{	35,	[bad_35]		},
/* uncertain */
		{	64,	[uncertain_64]	},
		{	65,	[uncertain_65]	},
		{	66,	[uncertain_66]	},
		{	67,	[uncertain_67]	},
		{	68,	[uncertain_68]	},
		{	69,	[uncertain_69]	},
		{	70,	[uncertain_70]	},
		{	71,	[uncertain_71]	},
		{	72,	[uncertain_72]	},
		{	73,	[uncertain_73]	},
		{	74,	[uncertain_74]	},
		{	75,	[uncertain_75]	},
		{	76,	[uncertain_76]	},
		{	77,	[uncertain_77]	},
		{	78,	[uncertain_78]	},
		{	79,	[uncertain_79]	},
		{	80,	[uncertain_80]	},
		{	81,	[uncertain_81]	},
		{	82,	[uncertain_82]	},
		{	83,	[uncertain_83]	},
		{	84,	[uncertain_84]	},
		{	85,	[uncertain_85]	},
		{	86,	[uncertain_86]	},
		{	87,	[uncertain_87]	},
		{	88,	[uncertain_88]	},
		{	89,	[uncertain_89]	},
		{	90,	[uncertain_90]	},
		{	91,	[uncertain_91]	},
		{	92,	[uncertain_92]	},
		{	93,	[uncertain_93]	},
		{	94,	[uncertain_94]	},
		{	95,	[uncertain_95]	},
/* good */
		{	128,[good_128]		},
		{	129,[good_129]		},
		{	130,[good_130]		},
		{	131,[good_131]		},
		{	132,[good_132]		},
		{	133,[good_133]		},
		{	134,[good_134]		},
		{	135,[good_135]		},
		{	136,[good_136]		},
		{	137,[good_137]		},
		{	138,[good_138]		},
		{	139,[good_139]		},
		{	140,[good_140]		},
		{	141,[good_141]		},
		{	142,[good_142]		},
		{	143,[good_143]		},
		{	144,[good_144]		},
		{	145,[good_145]		},
		{	146,[good_146]		},
		{	147,[good_147]		},
		{	148,[good_148]		},
		{	149,[good_149]		},
		{	150,[good_150]		},
		{	151,[good_151]		},
		{	152,[good_152]		},
		{	153,[good_153]		},
		{	154,[good_154]		},
		{	155,[good_155]		},
		{	160,[good_160]		},
		{	161,[good_161]		},
		{	162,[good_162]		},
		{	163,[good_163]		}
	}
	HANDLING	READ;
}

VARIABLE trans1_secondary_value_2_unit
{
   LABEL         [trans_secondary_value_2_unit];
   HELP          [trans_secondary_value_2_unit_help];
   CLASS         CONTAINED;
   	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	FUNC1_DEFAULT_UNIT ;
		{ 1018,  [ft],			[ft_help]			},
		{ 1010,  [meter],			[meter_help]		},
		{ 1130,  [PA],			[PA_help]		},
		{ 1138,  [mbar],			[mbar_help]		},
		{ 1141,  [psi],			[psi_help]		}
	}
   HANDLING      READ & WRITE;
}

VARIABLE trans1_sensor_offset
{
   LABEL         [trans_sensor_offset];
   HELP          [trans_sensor_offset_help];
   CLASS         CONTAINED;
   TYPE          FLOAT;
   HANDLING      READ & WRITE;
}

VARIABLE trans1_calibration_type
{
	LABEL		[trans_lev_calibration_type];	
	HELP		[trans_lev_calibration_type_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
	VALIDITY	VALID_LEVEL_HYDRO
}

VARIABLE trans1_cal_point_lo
{
   LABEL         [trans_cal_point_lo];
   HELP          [trans_cal_point_lo_help];
   CLASS         CONTAINED;
   TYPE          FLOAT;
   HANDLING      READ & WRITE;
}

VARIABLE trans1_cal_point_hi
{
   LABEL         [trans_cal_point_hi];
   HELP          [trans_cal_point_hi_help];
   CLASS         CONTAINED;
   TYPE          FLOAT;
   HANDLING      READ & WRITE;
}

VARIABLE trans1_level_lo
{
   LABEL         [trans_level_lo];
   HELP          [trans_level_lo_help];
   CLASS         CONTAINED;
   TYPE          FLOAT;
   HANDLING      READ & WRITE;
}

VARIABLE trans1_level_hi
{
   LABEL         [trans_level_hi];
   HELP          [trans_level_hi_help];
   CLASS         CONTAINED;
   TYPE          FLOAT;
   HANDLING      READ & WRITE;
}

VARIABLE trans1_level_offset
{
   LABEL         [trans_lev_zero_offset];
   HELP          [trans_lev_zero_offset_help];
   CLASS         CONTAINED;
   TYPE          FLOAT;
   HANDLING      READ & WRITE;
}

VARIABLE trans1_lin_type
{
	LABEL		[trans_lin_type];	
	HELP		[trans_lin_type_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{ 0,  [linear]      }
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_lin_diameter
{
   LABEL         [trans_lin_diameter];
   HELP          [trans_lin_diameter_help];
   CLASS         CONTAINED;
   TYPE          FLOAT
   {
     DEFAULT_VALUE    100;
   }
   HANDLING      READ & WRITE;
}

VARIABLE trans1_lin_volume
{
   LABEL         [trans_lin_volume];
   HELP          [trans_lin_volume_help];
   CLASS         CONTAINED;
   TYPE          FLOAT
   {
     DEFAULT_VALUE    100;
   }
   HANDLING      READ & WRITE;
}

VARIABLE trans1_sensor_high_limit
{
   LABEL         [trans_sensor_upper_limit];
   HELP          [trans_sensor_upper_limit_help];
   CLASS         CONTAINED;
   TYPE          FLOAT;
   HANDLING      READ;
}

VARIABLE trans1_sensor_low_limit
{
   LABEL         [trans_sensor_lower_limit];
   HELP          [trans_sensor_lower_limit_help];
   CLASS         CONTAINED;
   TYPE          FLOAT;
   HANDLING      READ;
}

VARIABLE trans1_max_sensor_value
{
   LABEL         [trans_max_sensor_value];
   HELP          [trans_max_sensor_value_help];
   CLASS         CONTAINED;
   TYPE          FLOAT;
   HANDLING      READ & WRITE;
}

VARIABLE trans1_min_sensor_value
{
   LABEL         [trans_min_sensor_value];
   HELP          [trans_min_sensor_value_help];
   CLASS         CONTAINED;
   TYPE          FLOAT;
   HANDLING      READ & WRITE;
}

VARIABLE trans1_temperature
{
	LABEL		[trans_lev_temperature];	
	HELP		[trans_lev_temperature_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE trans1_temperature_unit
{
	LABEL		[trans_temperature_unit];
	HELP		[trans_temperature_unit_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	1001;
/* Temperature */
		{ 1001,  [degC],		[degC_help]		},
		{ 1002,  [degF],		[degF_help]		},
		{ 1003,  [degR],		[degR_help]		},
		{ 1000,  [Kelvin],		[Kelvin_help]	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_max_temperature
{
	LABEL		[trans_lev_max_temperature];	
	HELP		[trans_lev_max_temperature_help];
	CLASS		CONTAINED;
	TYPE		FLOAT;
	HANDLING	READ & WRITE;
}

VARIABLE trans1_min_temperature
{
	LABEL		[trans_lev_min_temperature];	
	HELP		[trans_lev_min_temperature_help];
	CLASS		CONTAINED;
	TYPE		FLOAT;
	HANDLING	READ & WRITE;
}

VARIABLE trans1_index
{
	LABEL		[lin_tab_entry];
	HELP		[lin_tab_entry_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

VARIABLE trans1_tab_min_number
{
	LABEL		[lin_tab_min_number];
	HELP		[lin_tab_min_number_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE trans1_tab_max_number
{
	LABEL		[lin_tab_max_number];
	HELP		[lin_tab_max_number_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}
VARIABLE trans1_tab_op_code
{
	LABEL		[lin_tab_op_code];
	HELP		[lin_tab_op_code_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

VARIABLE trans1_tab_status
{
	LABEL		[lin_tab_status];
	HELP		[lin_tab_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		{	0,	[lin_tab_status_NOT_INIT]				},
		{	1,	[lin_tab_status_GOOD]					},
		{	2,	[lin_tab_status_NOT_INC]				},
		{	3,	[lin_tab_status_NOT_DEC]				},
		{	4,	[lin_tab_status_NOT_ENOUGH_VALUES]		},
		{	5,	[lin_tab_status_TOO_MANY_VALUES]		},
		{	6,	[lin_tab_status_GRADIENT]				}
	}
	HANDLING	READ;
}

VARIABLE trans1_tab_actual_number
{
	LABEL		[trans_tab_actual_number];
	HELP		[trans_tab_actual_number_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}




/***********************************************************************/
/*    Unit relations                                                   */
/***********************************************************************/


/* Level Transducer Block	*/

UNIT TB_LEVEL_UNIT
{
	trans1_level_unit:
	
	trans1_level,
	trans1_full_cal,
	trans1_zero_offset,
	trans1_cylinder_diameter
}

UNIT TB_TEMPERATURE_UNIT
{
	trans1_temperature_unit:	
	trans1_temperature,
	trans1_max_temperature,
	trans1_min_temperature,
}

/* Function Block Analog Input */
UNIT AI_PV_SCALE_UNIT
{
	/* func1_AI_pv_unit: */
	trans1_level_unit:
	
	func1_AI_pv_upper_range_value,
	func1_AI_pv_lower_range_value,
	func1_AI_simulate_value
}

UNIT AI_OUT_SCALE_UNIT
{
	func1_AI_out_unit:

	func1_AI_out_value,
	func1_AI_out_upper_range_value,
	func1_AI_out_lower_range_value,
	func1_AI_hi_hi_lim,
	func1_AI_hi_lim,
	func1_AI_lo_lim,
	func1_AI_lo_lo_lim,
	func1_AI_hi_hi_alm_value,
	func1_AI_hi_alm_value,
	func1_AI_lo_alm_value,
	func1_AI_lo_lo_alm_value,
	func1_AI_alarm_hys
}


/*******************************************************************************/
/*****	MENU Bar  **************************************************************/
/*******************************************************************************/

MENU Menu_Main_Specialist
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_S_Device,
		Menu_S_View,
		Menu_S_Options,
		Menu_Help
	}
}

MENU Menu_Main_Maintenance
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_M_Device,
		Menu_M_View,
		Menu_M_Options,
		Menu_Help
	}
}

/*---------------------------------------------------------------------*/
/*    Menu: Device													   */
/*---------------------------------------------------------------------*/

MENU Menu_S_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_NodeAddress,
		SEPARATOR,
		std_LoadinDevice,										
		std_LoadinPC,
		SEPARATOR,
		Menu_simulation,
		OnlineDialog_reset,
		SEPARATOR,
		OnlineDialog_sensor_trim
	}
}

MENU Menu_M_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_LoadinDevice,										
		std_LoadinPC											
	}
}

MENU Menu_simulation
{
	LABEL		[menu_dialog_simulation];
	ITEMS
	{
		OnlineDialog_simulation_func1,
	}
}


METHOD std_NodeAddress
{
	LABEL		[menu_Device_NodeAddress];
	DEFINITION
	{
	}
}

METHOD std_LoadinDevice
{
	LABEL		[menu_Device_LoadinDevice];
	DEFINITION
	{
	}
}

METHOD std_LoadinPC
{
	LABEL		[menu_Device_LoadinPC];
	DEFINITION
	{
	}
}

/*******************************************************************************/
/*****	Online-Windows  ********************************************************/
/*******************************************************************************/

MENU OnlineWindow_display
{
	LABEL		[menu_dialog_display];
	ITEMS
	{
		Page_display_func1,
		Page_display_measure,
	}
}

MENU Page_display_measure
{
	LABEL		[menu_dialog_display_measure];
	ITEMS
	{
		BarVal_pv_display,
		trans1_temperature
	}
}

MENU BarVal_pv_display
{
	LABEL		[trans_lev_level];
	ITEMS
	{
		trans1_level,
		func1_AI_pv_lower_range_value (READ_ONLY),
		func1_AI_pv_upper_range_value (READ_ONLY)
	}
}


MENU OnlineWindow_diagnosis
{
	LABEL		[menu_dialog_diagnosis];
	ITEMS
	{
		Page_diagnosis_general,
		Page_diagnosis_phys_block,
		Page_diagnosis_trans1,
		Page_diagnosis_func1
	}
}

/*******************************************************************************/
/*****	Online-Dialogs  ********************************************************/
/*******************************************************************************/

MENU OnlineDialog_sensor_trim
{
	LABEL		[menu_dialog_sensor_trim];
	ITEMS
	{
		Page_cal_point_lo,
		Page_cal_point_hi
	}
}


MENU Page_cal_point_lo
{
	LABEL		[menu_dialog_sensor_trim_cal_point_lo];
	ITEMS
	{
		trans1_level,
		method_set
	}
}

MENU Page_cal_point_hi
{
	LABEL		[menu_dialog_sensor_trim_cal_point_hi];
	ITEMS
	{
		trans1_full_cal,
		trans1_level,
		method_set
	}
}


/*******************************************************************************/
/*****	Table: Specialist  *****************************************************/
/*******************************************************************************/

MENU Table_Main_Specialist
{
	LABEL	[menu_table_sensor_level];
	ITEMS
	{
		Tab_s_ident,
		Tab_s_input,
		Tab_s_output,
		Tab_s_certificates
	}
}

MENU Tab_s_input
{
	LABEL		[menu_input];
	ITEMS
	{
		trans1_st_rev,
		trans1_blk_class,
		trans1_level_unit,
		Tab_s_input_measrange,
		Tab_s_control_parameter,
		Tab_s_sensor_trim
	}
}

MENU Tab_s_input_measrange
{
	LABEL		[menu_input_measrange];
	ITEMS
	{
		trans1_sensor_low_limit,	
		trans1_sensor_high_limit
	}
}


MENU Tab_s_control_parameter
{
	LABEL [menu_control_parameter] ;
	ITEMS
	{
		trans1_temperature_unit,
	}
}

MENU Tab_s_sensor_trim
{
	LABEL [menu_input_trim] ;
	ITEMS
	{
		trans1_level_lo (READ_ONLY),
		trans1_level_hi (READ_ONLY)
	}
}

MENU Tab_s_output
{
	LABEL		[menu_output];
	ITEMS
	{
		Tab_s_func1
	}
}

MENU Tab_s_certificates
{
	LABEL		[menu_certificates];
	ITEMS
	{
		phys_device_certification	(READ_ONLY)
	}
}


/*******************************************************************************/
/*****	Table: Maintenance  ****************************************************/
/*******************************************************************************/

MENU Table_Main_Maintenance
{
	LABEL	[menu_table_sensor_level];
	ITEMS
	{
		trans1_blk_class,
		Tab_m_ident
	}
}

/*******************************************************************************/
/*****	Methods		************************************************************/
/*******************************************************************************/

METHOD method_set
{
	LABEL		[transfer];
	HELP		[transfer_help];
	DEFINITION
	{
	}
}

METHOD method_preset_alarm
{
	CLASS		INPUT;
	DEFINITION
	{
		float fValue;
		
		fValue = fvar_value(func1_AI_hi_hi_lim);
		fassign(func1_AI_hi_hi_lim, FLOAT_MAX);
		WriteCommand(write_func1_AI_hi_hi_lim);
		fassign(func1_AI_hi_hi_lim, fValue);
		
		fValue = fvar_value(func1_AI_lo_lo_lim);
		fassign(func1_AI_lo_lo_lim, FLOAT_MIN);
		WriteCommand(write_func1_AI_lo_lo_lim);
		fassign(func1_AI_lo_lo_lim, fValue);
	}
}


/*******************************************************************************/
/*****	Commands  **************************************************************/
/*******************************************************************************/

MENU download_variables
{
	LABEL		[menu_load_to_PC];
	ITEMS
	{
	/* PHYSICAL BLOCK ---------------------	*/
		phys_blk_reserve,
		phys_blk_object,
		phys_blk_parent_class,
		phys_blk_class,
		phys_blk_dd_reference,
		phys_blk_dd_rev,
		phys_blk_profile,
		phys_blk_profile_rev,
		phys_blk_execution_time,
		phys_blk_highest_rel_offset,
		phys_blk_index_view_1,
		phys_blk_num_view_lists,
		phys_st_rev,
		phys_tag_desc,
		phys_strategy,
		phys_alert_key,
		phys_target_mode,
		phys_actual_mode,
		phys_permitted_mode,
		phys_normal_mode,
		phys_current_state_alarm_sum,
		phys_unacknowledged_state_alarm_sum,
		phys_unreported_state_alarm_sum,
		phys_disabled_state_alarm_sum,
		phys_software_rev,
		phys_hardware_rev,
		phys_device_man_id,
		phys_device_id,
		phys_device_ser_num,
		phys_diagnosis,
		phys_diagnosis_mask,
		phys_diagnosis_extension,
		phys_diagnosis_extension_mask,
		phys_device_certification,
		phys_security_locking,
		phys_descriptor,
		phys_message,
		phys_install_date,
		phys_ident_number,

	/* TRANDSDUCER BLOCK ------------------	*/
		trans1_blk_reserve,
		trans1_blk_object,
		trans1_blk_parent_class,
		trans1_blk_class,
		trans1_blk_dd_reference,
		trans1_blk_dd_rev,
		trans1_blk_profile,
		trans1_blk_profile_rev,
		trans1_blk_execution_time,
		trans1_blk_highest_rel_offset,
		trans1_st_rev,
		trans1_tag_desc,
		trans1_strategy,
		trans1_alert_key,
		trans1_target_mode,
		trans1_actual_mode,
		trans1_permitted_mode,
		trans1_normal_mode,
		trans1_current_state_alarm_sum,
		trans1_unacknowledged_state_alarm_sum,
		trans1_unreported_state_alarm_sum,
		trans1_disabled_state_alarm_sum,
		trans1_sensor_high_limit,
		trans1_sensor_low_limit,
		trans1_level,
		trans1_level_unit,
		trans1_sensor_value,
		trans1_temperature,
		trans1_temperature_unit,
		trans1_max_temperature,
		trans1_min_temperature,
		trans1_lin_type,
		trans1_characteristic_table_index,
		trans1_characteristic_table_input_value,
		trans1_characteristic_table_output_value,
		trans1_characteristic_lin_op_code,
		trans1_characteristic_def_max,
		trans1_characteristic_def_min,
		trans1_characteristic_lin_status,
		trans1_cylinder_diameter,
		trans1_cylinder_volume,
		trans1_level_lo,
		trans1_level_hi,
		IF (LEVEL_HYDRO)
		{		
			trans1_calibration_type,
		}	
			
	/* FUNCTION BLOCK 1: ANALOG INPUT -----	*/
		FUNC1_LOAD_TO_PC
	}
}

MENU upload_variables
{
	LABEL		[menu_load_to_device];
	ITEMS
	{
	/* PHYSICAL BLOCK, STANDARD PARAMETER	*/
       	 phys_tag_desc,
	/* PHYSICAL BLOCK, ADDITIONAL PARAMETER	*/
	phys_descriptor,
	phys_message,
	phys_install_date,
	phys_ident_number,

	/* TRANDSDUCER BLOCK, STANDARD PARAMETER	*/
	/* TRANDSDUCER BLOCK, ADDITIONAL PARAMETER	*/
		trans1_level_unit,
		trans1_temperature_unit,
		trans1_cylinder_diameter,
		trans1_cylinder_volume,
	/* TRANDSDUCER BLOCK, ADDITIONAL PARAMETER (ECHO LEVEL) */

		IF (LEVEL_HYDRO)
		{
			trans1_pressure_unit,
		}

		FUNC1_LOAD_TO_DEVICE
	}
}

/******************* COMMAND ****************************************************************/

COMMAND read_trans1_primary_value
{
	BLOCK transducer_block_1;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_primary_value_value, trans1_primary_value_status		
		}
	}
}

COMMAND  read_trans1_primary_value_unit
{
     BLOCK transducer_block_1;
     INDEX 9;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_primary_value_unit
          }
     }
}
 
COMMAND  write_trans1_primary_value_unit
{
     BLOCK transducer_block_1;
     INDEX 9;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_primary_value_unit
          }
          REPLY
          {
          }
     }
}

COMMAND read_trans1_level
{
	BLOCK transducer_block_1;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_level
		}
	}
}

COMMAND read_trans1_level_unit
{
	BLOCK transducer_block_1;
	INDEX 11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_level_unit
		}
	}
}

COMMAND write_trans1_level_unit
{
	BLOCK transducer_block_1;
	INDEX 11;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_level_unit
		}
		REPLY
		{
		}
	}
}

COMMAND  read_trans1_sensor_value
{
     BLOCK transducer_block_1;
     INDEX 12;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_sensor_value
          }
     }
}

COMMAND  read_trans1_sensor_unit
{
     BLOCK transducer_block_1;
     INDEX 13;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_sensor_unit
          }
     }
}
 
COMMAND  write_trans1_sensor_unit
{
     BLOCK transducer_block_1;
     INDEX 13;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_sensor_unit
          }
          REPLY
          {
          }
     }
}

COMMAND read_trans1_secondary_value_1
{
	BLOCK transducer_block_1;
	INDEX 14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_secondary_value_1_value, trans1_secondary_value_1_status		
		}
	}
}

COMMAND  read_trans1_secondary_value_1_unit
{
     BLOCK transducer_block_1;
     INDEX 15;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_secondary_value_1_unit
          }
     }
}
 
COMMAND  write_trans1_secondary_value_1_unit
{
     BLOCK transducer_block_1;
     INDEX 15;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_secondary_value_1_unit
          }
          REPLY
          {
          }
     }
}

COMMAND read_trans1_secondary_value_2
{
	BLOCK transducer_block_1;
	INDEX 16;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_secondary_value_2_value, trans1_secondary_value_2_status		
		}
	}
}

COMMAND  read_trans1_secondary_value_2_unit
{
     BLOCK transducer_block_1;
     INDEX 17;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_secondary_value_2_unit
          }
     }
}
 
COMMAND  write_trans1_secondary_value_2_unit
{
     BLOCK transducer_block_1;
     INDEX 17;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_secondary_value_2_unit
          }
          REPLY
          {
          }
     }
}

COMMAND  read_trans1_sensor_offset
{
     BLOCK transducer_block_1;
     INDEX 18;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_sensor_offset
          }
     }
}
 
COMMAND  write_trans1_sensor_offset
{
     BLOCK transducer_block_1;
     INDEX 18;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_sensor_offset
          }
          REPLY
          {
          }
     }
}

COMMAND write_trans1_calibration_type
{
	BLOCK transducer_block_1;
	INDEX 19;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_calibration_type
		}
		REPLY
		{
		}
	}
}
 
COMMAND  write_trans1_calibration_type
{
     BLOCK transducer_block_1;
     INDEX 19;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_calibration_type
          }
          REPLY
          {
          }
     }
}

COMMAND  read_trans1_cal_point_lo
{
     BLOCK transducer_block_1;
     INDEX 20;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_cal_point_lo
          }
     }
}
 
COMMAND  write_trans1_cal_point_lo
{
     BLOCK transducer_block_1;
     INDEX 20;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_cal_point_lo
          }
          REPLY
          {
          }
     }
}
COMMAND  read_trans1_cal_point_hi
{
     BLOCK transducer_block_1;
     INDEX 21;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_cal_point_hi
          }
     }
}
 
COMMAND  write_trans1_cal_point_hi
{
     BLOCK transducer_block_1;
     INDEX 21;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_cal_point_hi
          }
          REPLY
          {
          }
     }
}
COMMAND  read_trans1_level_lo
{
     BLOCK transducer_block_1;
     INDEX 22;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_level_lo
          }
     }
}
 
COMMAND  write_trans1_level_lo
{
     BLOCK transducer_block_1;
     INDEX 22;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_level_lo
          }
          REPLY
          {
          }
     }
}
COMMAND  read_trans1_level_hi
{
     BLOCK transducer_block_1;
     INDEX 23;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_level_hi
          }
     }
}
 
COMMAND  write_trans1_level_hi
{
     BLOCK transducer_block_1;
     INDEX 23;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_level_hi
          }
          REPLY
          {
          }
     }
}
COMMAND  read_trans1_level_offset
{
     BLOCK transducer_block_1;
     INDEX 24;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_level_offset
          }
     }
}
 
COMMAND  write_trans1_level_offset
{
     BLOCK transducer_block_1;
     INDEX 24;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_level_offset
          }
          REPLY
          {
          }
     }
}

COMMAND read_trans1_lin_type
{
	BLOCK transducer_block_1;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_lin_type
		}
	}
}

COMMAND write_trans1_lin_type
{
	BLOCK transducer_block_1;
	INDEX 25;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_lin_type
		}
		REPLY
		{
		}
	}
}

COMMAND  read_trans1_lin_diameter
{
     BLOCK transducer_block_1;
     INDEX 26;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_lin_diameter
          }
     }
}
 
COMMAND  write_trans1_lin_diameter
{
     BLOCK transducer_block_1;
     INDEX 26;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_lin_diameter
          }
          REPLY
          {
          }
     }
}
COMMAND  read_trans1_lin_volume
{
     BLOCK transducer_block_1;
     INDEX 27;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_lin_volume
          }
     }
}
 
COMMAND  write_trans1_lin_volume
{
     BLOCK transducer_block_1;
     INDEX 27;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_lin_volume
          }
          REPLY
          {
          }
     }
}
COMMAND  read_trans1_sensor_high_limit
{
     BLOCK transducer_block_1;
     INDEX 28;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_sensor_high_limit
          }
     }
}
 
COMMAND  read_trans1_sensor_low_limit
{
     BLOCK transducer_block_1;
     INDEX 29;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_sensor_low_limit
          }
     }
}
 
COMMAND  read_trans1_max_sensor_value
{
     BLOCK transducer_block_1;
     INDEX 30;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_max_sensor_value
          }
     }
}
 
COMMAND  write_trans1_max_sensor_value
{
     BLOCK transducer_block_1;
     INDEX 30;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_max_sensor_value
          }
          REPLY
          {
          }
     }
}
COMMAND  read_trans1_min_sensor_value
{
     BLOCK transducer_block_1;
     INDEX 31;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_min_sensor_value
          }
     }
}
 
COMMAND  write_trans1_min_sensor_value
{
     BLOCK transducer_block_1;
     INDEX 31;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_min_sensor_value
          }
          REPLY
          {
          }
     }
}

COMMAND read_trans1_temperature
{
	BLOCK transducer_block_1;
	INDEX 32;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_temperature
		}
	}
}

COMMAND read_trans1_temperature_unit
{
	BLOCK transducer_block_1;
	INDEX 33;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_temperature_unit
		}
	}
}

COMMAND write_trans1_temperature_unit
{
	BLOCK transducer_block_1;
	INDEX 33;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_temperature_unit
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_max_temperature
{
	BLOCK transducer_block_1;
	INDEX 34;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_max_temperature
		}
	}
}

COMMAND write_trans1_max_temperature
{
	BLOCK transducer_block_1;
	INDEX 34;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_max_temperature
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_min_temperature
{
	BLOCK transducer_block_1;
	INDEX 35;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_min_temperature
		}
	}
}

COMMAND write_trans1_min_temperature
{
	BLOCK transducer_block_1;
	INDEX 35;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_min_temperature
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_index
{
	BLOCK transducer_block_1;
	INDEX 36;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_index
		}
	}
}

COMMAND write_trans1_index
{
	BLOCK transducer_block_1;
	INDEX 36;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_index
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans1_tab_min_number
{
	BLOCK transducer_block_1;
	INDEX 38;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_tab_min_number
		}
	}
}

COMMAND read_trans1_tab_max_number
{
	BLOCK transducer_block_1;
	INDEX 39;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_tab_max_number
		}
	}
}

COMMAND read_trans1_tab_op_code
{
	BLOCK transducer_block_1;
	INDEX 40;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_tab_op_code
		}
	}
}

COMMAND write_trans1_tab_op_code
{
	BLOCK transducer_block_1;
	INDEX 40;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_tab_op_code
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_tab_status
{
	BLOCK transducer_block_1;
	INDEX 41;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_tab_status
		}
	}
}

COMMAND read_trans1_tab_actual_number
{
	BLOCK transducer_block_1;
	INDEX 42;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_tab_actual_number
		}
	}
}


/*************************************************************************************************************/

